#####################################################################################################
########################################## HELPER FUNCTIONS #########################################
#####################################################################################################


vec.pac= c(
  
  # Data utilities
  "fastDummies"
  
  
  
) 

package.check <- lapply(
  vec.pac,
  FUN = function(x) {
    if (!require(x, character.only = TRUE)) {
      install.packages(x, dependencies = TRUE)
      library(x, character.only = TRUE)
    }
  }
)





### This function transforms categorical variable of a dataframe into factors 
### Input :  dataframe, name of categorical variables column 
### Output  :  transformed dataframe

categ_to_factors <- function(df, categ_var){
  df_new <- df
  for(var in categ_var){
    df_new[,var] <- as.factor(df[,var])}
  return(df_new)
}


# This function allow you to identify binary and continuous variables
### Input :  dataframe, variables to test
### Output  :  vector gathering the list of continuous, categorical and binary variables 
identify_categ_bin <- function(controls){
  categ_var=c()
  bin_var=c()
  cont_var=c()
  for(covariate in colnames(controls)){
    # cat(covariate)
    # cat(": ")
    if (length(unique(controls[,covariate]))==2){
      bin_var <- c(bin_var,covariate)
     # cat(' \n This is a binary variable \n')
    }
    if (length(unique(controls[,covariate]))>2 & length(unique(controls[,covariate]))<10){
      categ_var <- c(categ_var,covariate)
     # cat('\n This is a continuous variable \n')
      
    }
    if (length(unique(controls[,covariate]))>=10){
      cont_var <- c(cont_var,covariate)
    #  cat('\n This is a continuous variable \n')
      }
  }
  return(list(cont_var,categ_var,bin_var))
}


# This function allow you to create the architecture for results 
### Input :  name of the experiment folder, outcome variable, winsorization quantile
### Output  :  create all architecture and give you a list of path 

create_files = function(name_of_experiment, y, treatment_arm_name){
  
  # First folder with the name of you experiment (example : TEST_TUNNING100)
  path_for_experiment = paste('results',name_of_experiment,sep='/')
  dir.create(path_for_experiment)
  
  # Folder for the outcome
  outcome_folder <- paste(path_for_experiment, y, sep = "/")
  dir.create(outcome_folder)
  
  #setwd(results_folder)
  cat("\n Results will be located in: ")
  cat(outcome_folder)
  
  # We seperate for different winsorization 
  # winsorization_folder <- paste(outcome_folder,paste('winsor',winsorization_quantile,sep ="_"), sep='/')
  # dir.create(winsorization_folder)
  
  # We seperate for different treatment arm
  treatment_folder <- paste(outcome_folder,paste('treatment',treatment_arm_name,sep ="_"), sep='/')
  dir.create(treatment_folder)
  
  # Save B and S in the following folder
  B_and_S_folder <- paste(treatment_folder,'B_and_S', sep='/')
  dir.create(B_and_S_folder)
  
  # Save best tuning parameters in the following folder
  bestTune_folder <- paste(treatment_folder,'bestTune', sep='/')
  dir.create(bestTune_folder)
  
  # Save settings in the following folder:
  settings= 'settings'
  settings_folder <- paste(treatment_folder,settings, sep='/')
  dir.create(settings_folder)
  
  cat("\n Settings will be located in: ")
  cat(settings_folder)
  
  cat("\n B and S will be located in: ")
  cat(B_and_S_folder)
  
  # Save aux and main
  sample_folder <- paste(treatment_folder,'samples', sep='/')
  dir.create(sample_folder)
  
  cat("\n Auxiliary and main samples will be located in: ")
  cat(sample_folder)
  cat('\n')
  
  # Save models 
  # dir.create(dirname(name_settings_file("method", 1)))
  # cat("Models fitted on the first split are saved in: \n")
  # cat(dirname(name_settings_file("method", 1)))
  
  return(list(path_for_experiment=path_for_experiment,
              outcome_folder=outcome_folder,
              settings_folder = settings_folder,
              #winsorization_folder = winsorization_folder,
              B_and_S_folder = B_and_S_folder,
              sample_folder = sample_folder,
              treatment_folder = treatment_folder
  ))
  
}

# This function creates names for proxies files 
name_BS_file <- function(method, t, path_list){
  filename <- paste(method, 'B_and_S', sep = "_") 
  filename <- paste(filename, t, sep = "_") 
  filename <- paste("B_and_S", filename, sep = "/") 
  filename <- paste(path_list$treatment_folder, filename, sep = "/")
  filename <- paste(filename, "RData", sep = ".") 
  return(filename)
}

name_bestTune_file <- function(method, t, path_list){
  filename <- paste(method, 'bestTune', sep = "_") 
  filename <- paste(filename, t, sep = "_") 
  filename <- paste("bestTune", filename, sep = "/") 
  filename <- paste(path_list$treatment_folder, filename, sep = "/")
  filename <- paste(filename, "RData", sep = ".") 
  return(filename)
}


### This function transforms categorical variable of a dataframe into numeric 
### Input :  dataframe, name of categorical variables column 
### Output  :  categorical transformed variables

categorical_to_discrete <- function(df, categorical_names){
  categorical <- df %>% select_at(categorical_names)
  
  categorical <- data.frame(dummy_cols(categorical, 
                                       select_columns = categorical_names, 
                                       remove_first_dummy = TRUE, remove_selected_columns = TRUE)) 
  
  return(categorical)
}

### Imputation by median by group
imputation_median_by_group <- function(df, vars_group, vars_to_impute){
  for(var in vars_to_impute){
    df <- df %>% 
      tidyr::unite(group_imputation, all_of(vars_group), sep = "_", remove = FALSE)
    df <- eval(parse(text = paste0("transform(df,", var, " = ave(", var, ", group_imputation, FUN = function(x) replace(x, is.na(x), median(x, na.rm = T))))")))
  }
  return(df[ , !names(df) %in% c("group_imputation")])
}

### Imputation by mode by group
my_mode = function(x){
  return(names(sort(table(x), decreasing = T)[1]))
}

imputation_mode_by_group <- function(df, vars_group, vars_to_impute){
  for(var in vars_to_impute){
    df <- df %>% 
      tidyr::unite(group_imputation, all_of(vars_group), sep = "_", remove = FALSE)
    df <- eval(parse(text = paste0("transform(df,", var, " = ave(", var, ", group_imputation, FUN = function(x) replace(x, is.na(x), my_mode(x))))")))
  }
  return(df[ , !names(df) %in% c("group_imputation")])
}

### Imputation median for all 
imputation_median_for_all <- function(df, vars_to_impute){
  for(var in vars_to_impute){
    df[[var]] =  ifelse(is.na(df[[var]]), median(df[[var]] , na.rm = T), df[[var]])
  }
  return(df)
}


retrieve_results <- function(result_list){
  
  result <- sapply(result_list, unlist)
  name <- row.names(result)
  result <- rowMedians(result)
  result <- enframe(unlist(result) )
  result$name <- name
  into_col <- NULL
  for(i in 1:length(strsplit(name[[1]], "\\.")[[1]])){into_col <- c(into_col, paste('var',i, sep='_'))}
  output <- data.frame(result %>% separate(name, into = into_col,sep="\\."))
  
}
