################################METHODS FUNCTIONS########################

source("codes/0_config.R")
two_learner_continuous_function <- function(method, x, tune_param, y, datause, dataout, ind_u, path_list, name_BS_file, t, d){
### This function should be used only for CONTINUOUS outcomes.
### This function learns ML proxies for B and S using a two-learner structure, meaning that S (the CATE) is estimated 
### by estimating separatly E[Y |D = 0, X] (on control units from the AUX sample) and E[Y |D = 1, X] (on treated units from the AUX sample)
### and then taking the difference between these two quantities.


  x.method <- x[[method]]
  form         <- as.formula(paste(y, "~", x[[method]],sep=""))
  caret.method <- if(method == "rf"){"ranger"}else if(method == "glmnet_exp"){"glmnet"} else method
  
  #### 1. Learning E[Y |D = 1, X] ###################################################################################
  
  fitControl   <- trainControl(method = tune_param[[method]]$methodML, 
                               number = tune_param[[method]]$cv ,
                               repeats = tune_param[[method]]$rep, 
                               allowParallel = TRUE, 
                               verboseIter=FALSE, 
                               selectionFunction=tune_param[[method]]$select)
  if(method=="pcaNNet"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces, 
                           tuneLength=tune_param[[method]]$tune,
                           linout = TRUE,
                           MaxNWts=100000, 
                           maxit=10000))
    
    

  }else if(method =="rf"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces, 
                           num.trees=tune_param[[method]]$num_trees,
                           tuneLength=tune_param[[method]]$tune
                           )) # case.weights=additional_weight #
  }else if(method =="xgbTree"){
      arg          <- c(list(form=form, 
                             data = datause[ind_u,], 
                             method = caret.method,  
                             #tuneGrid = tune_param[[method]]$grid, 
                             tuneGrid = NULL,
                             tuneLength=tune_param[[method]]$tune,
                             trControl = fitControl, 
                             preProcess=tune_param[[method]]$proces
      )) 
  }else if(method =="gbm"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
                           ))  
  }else if(method =="glmnet"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
                           ))
  }else if(method =="glmnet_exp"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    ))
  }else if(method =="svmPoly"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    ))
  }else{
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces))  
    
  }
  
  # Learning E[Y |D = 1, X] on treated units from the AUX sample :
  fit.yz1      <- suppressWarnings(do.call(caret::train, arg))
  
  # Hyperparameters of the best model
  besttune_1   <- fit.yz1$bestTune
  
  # Mean Absolute Error of the final model on treated units from the AUX sample:
  perf_aux_1   <- getTrainPerf(fit.yz1)$TrainMAE
  
  # Evaluating E[Y |D = 1, X] on treated units from the MAIN sample: 
  my_z1x       <- predict(fit.yz1, newdata=dataout, type="raw")
  
  # Mean Absolute Error of the final model on treated unis from the MAIN sample:
  perf_main_1  <- MLmetrics::MAE(dataout[dataout[[d]] == 1, y], predict(fit.yz1, newdata=dataout[dataout[[d]]==1,],type = "raw"))
  
  
  #### 2. Learning E[Y |D = 0, X] ###################################################################################
  
  fitControl   <- trainControl(method = tune_param[[method]]$methodML, 
                               number = tune_param[[method]]$cv , 
                               repeats = tune_param[[method]]$rep, 
                               allowParallel = TRUE, 
                               verboseIter=FALSE, 
                               selectionFunction=tune_param[[method]]$select)
  if(method=="pcaNNet"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,],  
                           method = caret.method,  
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces, 
                           tuneLength=tune_param[[method]]$tune,
                           linout = TRUE,
                           MaxNWts=100000, 
                           maxit=10000))
  }else if(method =="rf"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,],  
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces,
                           num.trees=tune_param[[method]]$num_trees,
                           tuneLength=tune_param[[method]]$tune
                           )) #case.weights=additional_weight
  }else if(method =="xgbTree"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL,
                           tuneLength=tune_param[[method]]$tune,
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces
    )) 
  }else if(method =="gbm"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL,
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$process 
                           ))  
  }else if(method =="glmnet"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL,tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces
                           )) }
    else if(method =="glmnet_exp"){
      arg          <- c(list(form=form, 
                             data = datause[ind_u,],
                             method = caret.method,  
                             tuneGrid = NULL, 
                             tuneLength=tune_param[[method]]$tune, 
                             trControl = fitControl, 
                             preProcess=tune_param[[method]]$proces 
      ))
  }else if(method =="svmPoly"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    ))
  }else{
    arg          <- c(list(form=form, 
                           data=datause[-ind_u,], 
                           method=caret.method,  
                           tuneGrid=NULL,
                           tuneLength=tune_param[[method]]$tune, 
                           trControl=fitControl, 
                           preProcess=tune_param[[method]]$proces))
    
  }
  
  # Learning E[Y |D = 0, X] on control units from the AUX sample :
  fit.yz0      <- suppressWarnings(do.call(caret::train, arg))
  
  # Hyperparameters of the best model
  besttune_0   <- fit.yz0$bestTune 
  
  # Mean Absolute Error of the final model on control units from the AUX sample:
  perf_aux_0   <- getTrainPerf(fit.yz0)$TrainMAE
  
  # Evaluating E[Y |D = 0, X] on control units from the MAIN sample: 
  my_z0x       <- predict(fit.yz0, newdata=dataout, type="raw")
  
  # Mean Absolute Error of the final model on control unis from the MAIN sample:
  perf_main_0       <- MLmetrics::MAE(dataout[dataout[[d]] == 0, y], predict(fit.yz1, newdata=dataout[dataout[[d]]==0,],type = "raw"))
  
  
  #### 3. ML PROXIES ##############################################################################################
  
  ## B : ML proxy of the baseline effet (E[Y |D = 0, X]) on main sample
  ## S : ML proxy of the CATE (E[Y |D = 1, X] - E[Y |D = 0, X]) on main sample
  
  output <- list()
  output$B <- c(my_z0x)
  output$S <- c(my_z1x - my_z0x)
  output$id <- c(dataout$id)
  output$perf_aux_main_0 <- c(perf_aux_0, perf_main_0)
  output$perf_aux_main_1 <- c(perf_aux_1, perf_main_1)
  output$bestTune_0 <- c(besttune_0)
  output$bestTune_1 <- c(besttune_1)
  hist(c(my_z1x - my_z0x))
  
  
  return(output)
}




two_learner_binary_function <- function(method, x, tune_param, y, datause, dataout, ind_u, path_list, name_BS_file, t, d){
### This function should be used only for BINARY outcomes.
### This function learns ML proxies for B and S using a two-learner structure, meaning that S (the CATE) is estimated 
### by estimating separatly E[Y |D = 0, X] (on control units from the AUX sample) and E[Y |D = 1, X] (on treated units from the AUX sample)
### and then taking the difference between these two quantities.
  
  x.method <- x[[method]]
  form         <- as.formula(paste(y, "~",x[[method]],sep=""))
  caret.method <- if(method == "rf"){"ranger"}else if(method == "glmnet_exp"){"glmnet"} else method
  
  datause[[y]] = as.factor(datause[[y]])
  dataout[[y]] = as.factor(dataout[[y]])
  datause[[y]] = plyr::mapvalues(datause[[y]], levels(datause[[y]]), make.names(levels(datause[[y]]), unique=TRUE))
  dataout[[y]] = plyr::mapvalues(dataout[[y]], levels(dataout[[y]]), make.names(levels(dataout[[y]]), unique=TRUE))
  
  
  #### 1. Learning E[Y |D = 1, X] ###################################################################################
  
  fitControl   <- trainControl(method = tune_param[[method]]$methodML, 
                               number = tune_param[[method]]$cv ,
                               repeats = tune_param[[method]]$rep, 
                               classProbs = T, 
                               summaryFunction = twoClassSummary,
                               allowParallel = TRUE, 
                               verboseIter=FALSE, 
                               selectionFunction=tune_param[[method]]$select,
                               savePredictions = TRUE)
  if(method =="rf"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces, 
                           num.trees=tune_param[[method]]$num_trees
    )) 
  }else if(method =="xgbTree"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL,
                           tuneLength=tune_param[[method]]$tune,
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces
    )) 
  }else if(method =="gbm"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    )) 
  }else if(method =="glmnet"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           family="binomial",
                           preProcess=tune_param[[method]]$proces 
    ))
    }else if(method =="glmnet_exp"){
      arg          <- c(list(form=form, 
                             data = datause[ind_u,],
                             method = caret.method,  
                             tuneGrid = NULL, 
                             tuneLength=tune_param[[method]]$tune, 
                             trControl = fitControl, 
                             preProcess=tune_param[[method]]$proces 
      ))
  }else if(method =="svmPoly"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    ))
    }else{
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces))  
    
  }
  
  # Learning E[Y |D = 1, X] on treated units from the AUX sample :
  fit.yz1      <- suppressWarnings(do.call(caret::train, arg))
  
  # Hyperparameters of the best model
  besttune_1   <- fit.yz1$bestTune
  
  # Area Under the ROC Curve of the final model on treated units from the AUX sample:
  perf_aux_1   <- MLeval::evalm(fit.yz1,showplots = F, silent = T)$stdres[['Group 1']]['AUC-ROC', 'Score']
  
  # Evaluating E[Y |D = 1, X] on treated units from the MAIN sample: 
  my_z1x       <- predict(fit.yz1, newdata=dataout, type="prob")[,2]
  
  # AUC of the final model on treated unis from the MAIN sample:
  perf_main_1  <- MLmetrics::AUC(predict(fit.yz1, newdata = dataout[dataout[[d]]==1,],type = "prob")[,2],as.numeric(dataout[dataout[[d]]==1,y])-1)
  
  
  #### 2. Learning E[Y |D = 0, X] ###################################################################################
  
  fitControl   <- trainControl(method = tune_param[[method]]$methodML, 
                               number = tune_param[[method]]$cv , 
                               repeats = tune_param[[method]]$rep, 
                               classProbs = T, 
                               summaryFunction = twoClassSummary,
                               allowParallel = TRUE, 
                               verboseIter=FALSE, 
                               selectionFunction=tune_param[[method]]$select,
                               savePredictions = TRUE)
  if(method =="rf"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,],  
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces,
                           num.trees=tune_param[[method]]$num_trees
    )) 
  }else if(method =="xgbTree"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,], 
                           method = caret.method,  
                           #tuneGrid = tune_param[[method]]$grid, 
                           tuneGrid = NULL,
                           tuneLength=tune_param[[method]]$tune,
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces
    ))  
  }else if(method =="gbm"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL,
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$process 
    ))  
  }else if(method =="glmnet"){
    arg          <- c(list(form=form, 
                           data = datause[-ind_u,], 
                           method = caret.method,  
                           tuneGrid = NULL,tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           family="binomial",
                           preProcess=tune_param[[method]]$proces
    ))
    }else if(method =="glmnet_exp"){
      arg          <- c(list(form=form, 
                             data = datause[ind_u,],
                             method = caret.method,  
                             tuneGrid = NULL, 
                             tuneLength=tune_param[[method]]$tune, 
                             trControl = fitControl, 
                             preProcess=tune_param[[method]]$proces 
      ))
  }else if(method =="svmPoly"){
    arg          <- c(list(form=form, 
                           data = datause[ind_u,],
                           method = caret.method,  
                           tuneGrid = NULL, 
                           tuneLength=tune_param[[method]]$tune, 
                           trControl = fitControl, 
                           preProcess=tune_param[[method]]$proces 
    ))
    }else{
    arg          <- c(list(form=form, 
                           data=datause[-ind_u,], 
                           method=caret.method,  
                           tuneGrid=NULL,
                           tuneLength=tune_param[[method]]$tune, 
                           trControl=fitControl, 
                           preProcess=tune_param[[method]]$proces))  
    
  }
  
  # Learning E[Y |D = 0, X] on control units from the AUX sample :
  fit.yz0      <- suppressWarnings(do.call(caret::train, arg))
  
  # Hyperparameters of the best model
  besttune_0   <- fit.yz0$bestTune
  
  # Area Under the ROC Curve of the final model on control units from the AUX sample:
  perf_aux_0   <- MLeval::evalm(fit.yz0,showplots = F, silent = T)$stdres[['Group 1']]['AUC-ROC', 'Score']
  
  # Evaluating E[Y |D = 0, X] on control units from the MAIN sample: 
  my_z0x       <- predict(fit.yz0, newdata=dataout, type="prob")[,2]
  
  # AUC of the final model on control unis from the MAIN sample:
  perf_main_0  <- MLmetrics::AUC(predict(fit.yz0, newdata = dataout[dataout[[d]]==0,],type = "prob")[,2],as.numeric(dataout[dataout[[d]]==0,y])-1)
  
  
  #### 3. ML PROXIES ##############################################################################################
  
  
  output <- list()
  output$B <- c(my_z0x)
  output$S <- c(my_z1x - my_z0x)
  output$id <- c(dataout$id)
  output$perf_aux_main_0 <- c(perf_aux_0, perf_main_0)
  output$perf_aux_main_1 <- c(perf_aux_1, perf_main_1)
  output$bestTune_0 <- c(besttune_0)
  output$bestTune_1 <- c(besttune_1)
  hist(c(my_z1x - my_z0x))
  
  
  return(output)
}

single_learner_function <- function(method, x, tune_param, y, datause, dataout, ind_u, path_list ,name_BS_file, t, d){
  
# Not used for this work
  
}
