#delimit ;
use "$path\data_original\dji_midline.dta", clear;
* merge DESIGN DATA;
sort id8;
merge 1:1 id8 using "$path\data_original\designdata.dta";
		assert _merge==3;
		assert rsite==w1_id1;
		assert rfoyer==w1_id2;
		drop _merge;
		preserve;
* merge BASELINE data;
use "$path\data_original\dji_baseline.dta", clear;
keep id8 interviewdatenum- timeman_other wo_employed-members_shother_rel w_gaveopinion_index- w_partdecisionoth_index index_womendecision_std   index_womendecision_fa index_noneedpermission_std index_goesalone_std index_mobility_fa w_selfesteem- m_depression;
foreach var of varlist interviewdatenum-timeman_other wo_employed-members_shother_rel w_gaveopinion_index- w_partdecisionoth_index index_womendecision_std index_womendecision_fa index_noneedpermission_std index_goesalone_std index_mobility_fa w_selfesteem- m_depression {;
			rename `var' bs_`var';
			};
			drop bs_group_1-bs_treatment;
			sort id8;
save "$path\data_analysis\temp\baseline_outcomes.dta", replace;
restore;	
merge 1:1 id8 using "$path\data_analysis\temp\baseline_outcomes.dta"; 	
assert _merge==3;
drop _merge;



*********************************************************************************************************************;
* PREPARE ANALYSIS VARS;

* Time in months between baseline and follow-up week 3 interview;
gen w3_months_bs_fu= (w3_interviewdatenum - bs_interviewdatenum) / 30.33;
				label var w3_months_bs_fu "Time in months between baseline and follow-up (week 3) interview";  
* Age in months of youngest child at follow-up week 3survey; 	
gen agemonths_ych = int(bs_agemonths_ych + w3_months_bs_fu);
label var agemonths_ych "Age in months of youngest child at follow-up (week 3) interview";  
* some more cleaning;		
replace w1_f45_fdj=400 if w1_f45_fdj == 18400 & id8==12095;
replace w1_f45_fdj=800 if w1_f45_fdj == 18800 & id8==20567;
replace w1_f47_fdj=500 if w1_f47_fdj == 18500 & id8==19811;
replace w2_f44_fdj=800 if w2_f44_fdj == 18800 & id8==20591;
replace w3_f8 = 2 if id8== 13633;
***************************************;
* HH Members at Follow-up;
	* TO BE CORRECTED: nmembers is taking in account adults above 15 in week 1 and 3 and members>6 in week 2 (for some of the follow ups);
	* We count the number of members we have each week;
	foreach week in w1 w2 w3 {;
		gen `week'_nmembers = 0;
		foreach i of numlist 0/16 {;
			replace `week'_nmembers = `week'_nmembers + 1 if `week'_h1a_`i'==1;
			};
			};
	
	* we add new members form week 1 (they are not yet integrated inteh main roster as we did in week 2 and 3);
	foreach i of numlist 0/4 {;
		replace w1_nmembers = w1_nmembers + 1 if w1_h2_1_`i'!="";
		};
		
	* we turn to missing hh with 0 members; 
	foreach week in w1 w2 w3 {;	 
	 replace `week'_nmembers=. if `week'_nmembers==0;
	 };
	 
	egen nmembers = rowmean(w1_nmembers w2_nmembers w3_nmembers);
		replace nmembers = int(nmembers); 
		tab nmembers;
		label var nmembers "number of HH members"; 
				
	gen missroster= (nmembers==.);
	gen missroster_w1= (w1_nmembers==.);
	gen missroster_w2= (w2_nmembers==.);
	gen missroster_w3 = (w3_nmembers==.);
		label var missroster "1 if roster data missing among 3 weeks"; 
		label var missroster_w1 "1 if roster data missing in week 1"; 
		label var missroster_w2 "1 if roster data missing in week 2"; 
		label var missroster_w3 "1 if roster data missing in week 3"; 

		drop w1_nmembers w2_nmembers w3_nmembers;
		
***************************************;
***************************************;
* Expenses and budget share;

	* We identify missing data: woman sections;
	egen miss_expenses=rowmiss(w2_s* w2_e*);
		tab miss_expenses;
		replace miss_expenses=0 if miss_expenses<140;
		replace miss_expenses=1 if miss_expenses>=140;
		tab miss_expenses;
		label var miss_expenses "1 if expense data is missing";

		
	* We identify missing data: man sections;
	recode w2m_he* (88=.);
	egen mmiss_expenses=rowmiss(w2m_he*);		
		tab mmiss_expenses;
		replace mmiss_expenses=0 if mmiss_expenses<20;
		replace mmiss_expenses=1 if mmiss_expenses>=20;
		tab mmiss_expenses;
		label var mmiss_expenses "1 if expense data from man quest is missing";
	
	* Food expenditures last 30 days;
		gen exp_food=0 if miss_expenses==0;
			forval i=1/24 {;
				* Followups 1 2 3;
				replace exp_food=exp_food + (w2_e`i'_m * 30)   if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==1;
				replace exp_food=exp_food + (w2_e`i'_m * 4.3)  if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==2;
				replace exp_food=exp_food +  w2_e`i'_m         if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==3;
				* Followup 4;
				replace exp_food=exp_food + (w2_e`i'_mj * 30)   if w2_e`i'_mj >= 0 & w2_e`i'_mj!=. & w2_e`i'==1 & followup_n==4;
				replace exp_food=exp_food + (w2_e`i'_mh * 4.3)  if w2_e`i'_mh >= 0 & w2_e`i'_mh!=. & w2_e`i'==2 & followup_n==4;
				replace exp_food=exp_food +  w2_e`i'_mm         if w2_e`i'_mm >= 0 & w2_e`i'_mm!=. & w2_e`i'==3 & followup_n==4;
				};
			
			* we add e25 and e26 (other food expenditures);
			forval i=25/26 {;
				* Followups 1 2 3;
				replace exp_food=exp_food + (w2_e`i'_m * 30)   if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'c==1;
				replace exp_food=exp_food + (w2_e`i'_m * 4.3)  if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'c==2;
				replace exp_food=exp_food +  w2_e`i'_m         if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'c==3;
				* Followup 4;
				replace exp_food=exp_food + (w2_e`i'_mj * 30)   if w2_e`i'_mj >= 0 & w2_e`i'_mj!=. & w2_e`i'c==1 & followup_n==4;
				replace exp_food=exp_food + (w2_e`i'_mh * 4.3)  if w2_e`i'_mh >= 0 & w2_e`i'_mh!=. & w2_e`i'c==2 & followup_n==4;
				replace exp_food=exp_food +  w2_e`i'_m         if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'c==3 & followup_n==4;				
				};
	
			lab var exp_food "HH food expenditures last 30 days";
			
* CLEANING In next point we've identified that surveyor 1 and 9 during followup 1 and 2 computed monthly expenses independently of the frequency of purchases declared;
		* We correct this and we check data again;
		forval i=1/24 {;
				replace w2_e`i'=3 if (w2_id9_code==1 | w2_id9_code==9) & (followup_n==1 | followup_n==2) & inrange(w2_e`i', 1, 2); 
				};

*************************************************************************;
* We correct data on food expenses;
* In next point we've identified that surveyor 1 and 9 during followup 1 and 2 computed monthly expenses independently of the frequency of purchases declared;
		* We correct this and we check data again;
		forval i=1/24 {;
				replace w2_e`i'=3 if (w2_id9_code==1 | w2_id9_code==9) & (followup_n==1 | followup_n==2) & inrange(w2_e`i', 1, 2); 
				};
	
	* We analyze food declared with daily recall vs weekly and monthly recall;
			forval i=1/24 {;
				gen temp_foodday`i'= .;
				replace temp_foodday`i'=(w2_e`i'_m)*7   if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==1; 
				replace temp_foodday`i' = temp_foodday`i' / bs_members; 
				};
			forval i=1/24 {;
				gen temp_foodweek`i'= .;
				replace temp_foodweek`i'=(w2_e`i'_m)   if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==2; 
				replace temp_foodweek`i' = temp_foodweek`i' / bs_members; 
				};
			forval i=1/24 {;
				gen temp_foodmonth`i'= .;
				replace temp_foodmonth`i'=(w2_e`i'_m)/4.3   if w2_e`i'_m >= 0 & w2_e`i'_m!=. & w2_e`i'==3; 
				replace temp_foodmonth`i' = temp_foodmonth`i' / bs_members; 
				};
* There is 1 surveyors in followup 1 and 2 in followup 2 that seem to have declared expenses over the past 30 days independently from the frequency chosen;
				* We then correct the frequency;
			
				* We identify surveyor/followup problems;
				forval i=1/24 {;
					sum temp_foodday`i' if followup_n==3, detail;
					sort followup_n;
					by followup_n: egen tempmax`i' = max(temp_foodmonth`i');
					egen max`i' = mean(tempmax`i');
						drop tempmax`i'; 
					
					gen out`i' = (temp_foodday`i' > max`i' & temp_foodday`i'!=.);
					gen exp`i' = (temp_foodday`i'!=.);
					
					sort w2_id9_code followup_n;
					by w2_id9_code followup_n: egen nexp`i' = sum(exp`i');
					by w2_id9_code followup_n: egen nout`i' = sum(out`i');
					gen shareout`i' =  nout`i' / nexp`i';
					};
					
*************************************************************************;
* Health expenditures last 30 days;
		gen exp_health=0 if miss_expenses==0;
			foreach i of numlist 1/5 18/22 {;
				replace exp_health=exp_health + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
				};
			lab var exp_health "HH health expenditures last 30 days";
	* Education expenditures last 30 days;
		gen exp_education=0 if miss_expenses==0;
			foreach i in 6_1 6_2 6_3 6b 7 7b 23_1 23_2 23b 24 24b {;
				replace exp_education=exp_education + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
				};
		* we condition on children 6-15;
		replace exp_education=. if bs_enfant615==0;
		lab var exp_education "HH education expenditures last 30 days";
	* August education expenditures (only followup 2);
		gen exp_educaugust=0 if miss_expenses==0 & followup_n==2;
			foreach i of numlist 38/41 {;
				replace exp_educaugust=exp_educaugust + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
				};
		lab var exp_educaugust "HH education expenditures in August 2014 - Folow-up 2";
	* Clothes and shoes last 30 days;
		gen exp_clothes = 0 if miss_expenses==0;
			forval i=25/32 {;
			replace exp_clothes = exp_clothes + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
			};
			lab var exp_clothes "HH clothes & shoes expenditures last 30 days";
	* Celebrations & Religious last 30 days;
		gen exp_festivals = 0 if miss_expenses==0;
			forval i=34/37 {;
			replace exp_festivals = exp_festivals + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
			};
			lab var exp_festivals "HH celebration & religious expenditures last 30 days";
	* Leisure (from man questionnaire);
		gen exp_leisure = 0 if mmiss_expenses==0 & miss_expenses==0 ;
			foreach i in 1a 1b 2a 2b 3a 3b 3c 3d 3e 3f 4a {;
			replace exp_leisure = exp_leisure + (w2m_he`i' * 4.3) if w2m_he`i'!=. & w2m_he`i' >= 0;
			};
			lab var exp_leisure "HH expenditures in khat, tobacco, drinks&meals outside & entertainment last 30 days";		
	* Other expenditures;
		gen exp_other = 0 if miss_expenses==0;
		* Lodging, utilities, comm, etc. expenditures last 30 days;
		forval i=8/14 {;
			replace exp_other = exp_other + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
			};
		* Hygiene expenditures index last 30 days;
		forval i=15/17 {;
			replace exp_other = exp_other + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
			};
		* Travel;
		foreach i in 33 {;
			replace exp_other = exp_other + w2_s`i' if w2_s`i'!=. & w2_s`i' >= 0;
			};
		* Transport (from man questionnaire);
		foreach i in 5a 6a {;
			replace exp_other = exp_other + w2m_he`i' if w2m_he`i'!=. & w2m_he`i' >= 0;
			};
			lab var exp_other "HH other expenses (lodging, transport/travel, hygiene prod)";
	* Sum of NON-DURABLES;
	gen exp_nondurables = 0 if miss_expenses==0;
	foreach exptype in food health education clothes festivals leisure other {;
		replace exp_nondurables = exp_nondurables + exp_`exptype' if exp_`exptype'!=.;
		};
		lab var exp_nondurables "HH expenditures in non-durables last 30 days";	
	* Sum DURABLES;
	gen exp_durables = 0 if miss_expenses==0;
		forval i=1/7 {;
			replace exp_durables = exp_durables + w2_sb`i'm if w2_sb`i'm!=. & w2_sb`i'm >= 0;
			};
		lab var exp_durables "HH expenditures in durable goods last 30 days";	
	* TOTAL EXPENDITURES;
	gen exp_total = exp_nondurables + exp_durables;
		lab var exp_total "HH total expenditures last 30 days";	
	* Investment in productive assets;
		gen inv_assets = 0 if miss_expenses==0;
		forval i=8/10 {;
			replace inv_assets = inv_assets + w2_sb`i'm if w2_sb`i'm!=. & w2_sb`i'm >= 0;
			};
		lab var inv_assets "HH expenditures in land and livestock last 30 days";	
	* BUDGET SHARES;
		foreach exptype in food health education clothes festivals leisure other nondurables durables {;
			gen share_`exptype' = exp_`exptype' / exp_total;
				label var share_`exptype' "Share of `exptype' expenses in total expenditures";
			};
		
	* PER CAPITA expenditures;
		foreach exptype in food health education clothes festivals leisure other nondurables durables total {;
		gen exppc_`exptype' = exp_`exptype' / bs_members;
			label var exppc_`exptype' "Per capita HH expenditures in `exptype' last 30 days";
		};

****************************;
	** EXPENSES ROBUSTNESS; 
			
* ln;
	foreach var in exp_food exp_nondurables exp_total exppc_food exppc_nondurables exppc_durables exppc_total {;
		gen l`var' = ln(`var');
		};
	label var lexp_food "ln of HH food expenditures last 30 days";
	label var lexp_nondurables "ln of HH expenditures in non durables last 30 days";
	label var lexp_total "ln of HH total expenditures last 30 days";
	
	label var lexppc_food "ln of HH food per capita expenditures last 30 days";
	label var lexppc_nondurables "ln of HH per capita expenditures in non durables last 30 days";
	label var lexppc_total "ln of HH total per capita expenditures last 30 days";
	
	* We topcode top 0.5 of expenditure data;
		foreach var in 	exp_food exp_health exp_education exp_clothes exp_festivals exp_leisure exp_other exp_durables
						 {;
			gen tr05_`var'=`var';
			_pctile `var', p(99.5);
			replace tr05_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
			
			* for food we also trim the bottom 0.5%;
			foreach var in exp_food {; 
			_pctile `var', p(0.5);
			replace tr05_`var'=r(r1) if `var'<r(r1) & `var'>=0;
			};
		
			
		gen tr05_exp_nondurables = 0 if exp_nondurables!=.;
			foreach exptype in food health education clothes festivals leisure other {;
				replace tr05_exp_nondurables = tr05_exp_nondurables + tr05_exp_`exptype' if tr05_exp_`exptype'!=.;
				};
		
		gen tr05_exp_total = tr05_exp_nondurables;
			replace tr05_exp_total = tr05_exp_total + tr05_exp_durables if tr05_exp_durables!=.;	
	
		
		foreach group in food health education clothes festivals leisure other durables nondurables total {;
			lab var tr05_exp_`group' "HH `group' expenditures last 30 days - 0.5% topcoded";
			};
	
		* We topcode top 1 of expenditure data;
		foreach var in 	exp_food exp_health exp_education exp_clothes exp_festivals exp_leisure exp_other exp_durables {;
			gen tr1_`var'=`var';
			_pctile `var', p(99);
			replace tr1_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
			
			* for food we also trim the bottom 1%;
			foreach var in exp_food {; 
			_pctile `var', p(1);
			replace tr1_`var'=r(r1) if `var'<r(r1) & `var'>=0;
			};
		
			
		gen tr1_exp_nondurables = 0 if exp_nondurables!=.;
			foreach exptype in food health education clothes festivals leisure other {;
				replace tr1_exp_nondurables = tr1_exp_nondurables + tr1_exp_`exptype' if tr1_exp_`exptype'!=.;
				};
		
		
		gen tr1_exp_total = tr1_exp_nondurables;
			replace tr1_exp_total = tr1_exp_total + tr1_exp_durables if tr1_exp_durables!=.;	
	
		
		foreach group in food health education clothes festivals leisure other durables nondurables total {;
			lab var tr1_exp_`group' "HH `group' expenditures last 30 days - 1% topcoded";
			};
	
		* We topcode top 5 of expenditure data;
		foreach var in 	exp_food exp_health exp_education exp_clothes exp_festivals exp_leisure exp_other exp_durables {;
			gen tr5_`var'=`var';
			_pctile `var', p(95);
			replace tr5_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
			
			* for food we also trim the bottom 1%;
			foreach var in exp_food {; 
			_pctile `var', p(5);
			replace tr5_`var'=r(r1) if `var'<r(r1) & `var'>=0;
			};
		
			
		gen tr5_exp_nondurables = 0 if exp_nondurables!=.;
			foreach exptype in food health education clothes festivals leisure other {;
				replace tr5_exp_nondurables = tr5_exp_nondurables + tr5_exp_`exptype' if tr5_exp_`exptype'!=.;
				};
		
		
		gen tr5_exp_total = tr5_exp_nondurables;
			replace tr5_exp_total = tr5_exp_total + tr5_exp_durables if tr5_exp_durables!=.;	
	
		
		foreach group in food health education clothes festivals leisure other durables nondurables total {;
			lab var tr5_exp_`group' "HH `group' expenditures last 30 days - 5% topcoded";
			};
				
	* BUDGET SHARES;
		foreach exptype in food health education clothes festivals leisure other nondurables durables {;
			gen tr05_share_`exptype' = tr05_exp_`exptype' / tr05_exp_total;
				label var tr05_share_`exptype' "Share of `exptype' expenses in total expenditures - 0.5% topcoded";
			
			gen tr1_share_`exptype' = tr1_exp_`exptype' / tr1_exp_total;
				label var tr1_share_`exptype' "Share of `exptype' expenses in total expenditures - 1% topcoded";
				
			gen tr5_share_`exptype' = tr5_exp_`exptype' / tr5_exp_total;
				label var tr5_share_`exptype' "Share of `exptype' expenses in total expenditures - 5% topcoded";
				};
		
	* PER CAPITA expenditures;
		foreach exptype in food health education clothes festivals leisure other nondurables durables total {;
		gen tr05_exppc_`exptype' = tr05_exp_`exptype' / bs_members;
			label var tr05_exppc_`exptype' "Per capita HH expenditures in `exptype' last 30 days - 0.5% topcoded";
			
		gen tr1_exppc_`exptype' = tr1_exp_`exptype' / bs_members;
			label var tr1_exppc_`exptype' "Per capita HH expenditures in `exptype' last 30 days - 1% topcoded";	
		
		gen tr5_exppc_`exptype' = tr5_exp_`exptype' / bs_members;
			label var tr5_exppc_`exptype' "Per capita HH expenditures in `exptype' last 30 days - 5% topcoded";	
			};		
	
	* ln of per capita expenses, top coded;	
		foreach var in tr05_exppc_total tr05_exppc_nondurables tr05_exppc_food tr1_exppc_total tr1_exppc_nondurables tr1_exppc_food tr5_exppc_total tr5_exppc_nondurables tr5_exppc_food {;
			gen l`var' = ln(`var');
			};	
			
			label var ltr05_exppc_total "ln of HH total per capita expenditures last 30 days - 0.5% topcoded";
			label var ltr05_exppc_nondurables "ln of HH per capita expenditures in non durables last 30 days - 0.5% topcoded";
			label var ltr05_exppc_food "ln of HH food per capita expenditures last 30 days - 0.5% topcoded";			
			
			label var ltr1_exppc_total "ln of HH total per capita expenditures last 30 days - 1% topcoded";
			label var ltr1_exppc_nondurables "ln of HH per capita expenditures in non durables last 30 days - 1% topcoded";
			label var ltr1_exppc_food "ln of HH food per capita expenditures last 30 days - 1% topcoded";
			
			label var ltr5_exppc_total "ln of HH total per capita expenditures last 30 days - 5% topcoded";
			label var ltr5_exppc_nondurables "ln of HH per capita expenditures in non durables last 30 days - 5% topcoded";
			label var ltr5_exppc_food "ln of HH food per capita expenditures last 30 days - 5% topcoded";
	 
	 
***********************************************;
** Private woman and man expenditures: past 30 days;
	* Expenditures in FDJ;
	* Clothes & Shoes;  
	gen exp_husband_clothes=0 if miss_expenses==0;
			replace exp_husband = exp_husband + w2_s25 if w2_s25!=. & w2_s25 >= 0;
			label var exp_husband "Expenses in clothes for husband in last 30 days";
			
	gen exp_woman_clothes=0 if miss_expenses==0;
			replace exp_woman = exp_woman + w2_s26 if w2_s26!=. & w2_s26 >= 0;
			label var exp_woman_clothes "Expenses in clothes for benef in last 30 days";	
			
	gen exp_adultmen_clothes=0 if miss_expenses==0;
			replace exp_adultmen_clothes = exp_adultmen_clothes + w2_s27 if w2_s27!=. & w2_s27 >= 0;
			label var exp_adultmen_clothes "Expenses in clothes for other adult men in last 30 days";
			
	gen exp_adultwomen_clothes=0 if miss_expenses==0;
		replace exp_adultwomen_clothes = exp_adultwomen_clothes + w2_s28 if w2_s28!=. & w2_s28 >= 0;
			label var exp_adultwomen_clothes "Expenses in clothes for other adult women in last 30 days";  
			
	gen exp_children_clothes=0 if miss_expenses==0;
			foreach i in s29 s30 {;
				replace exp_children_clothes=exp_children_clothes + w2_`i' if w2_`i'!=. & w2_`i' >= 0;
				};
				label var exp_children_clothes "Expenses in clothes for children in last 30 days";			
	
	gen exp_husband_khat_tabac = 0 if mmiss_expenses==0;
			foreach i in he1a he2a{;
				replace exp_husband_khat_tabac=exp_husband_khat_tabac + (w2m_`i' * 4.3) if w2m_`i'!=. & w2m_`i' >= 0;
				};	
				label var exp_husband_khat_tabac "Expenses in khat & tobacco for husband in last 30 days";	
	
	gen exp_adultmen_khat_tabac = 0 if mmiss_expenses==0;
			foreach i in he1a he2a he1b he2b {;
				replace exp_adultmen_khat_tabac=exp_adultmen_khat_tabac + (w2m_`i' * 4.3) if w2m_`i'!=. & w2m_`i' >= 0;
				};	
				label var exp_adultmen_khat_tabac "Expenses in khat & tobacco for other adult men in last 30 days";	
	
	gen exp_woman_haircare = 0 if miss_expenses==0;
			replace exp_woman_haircare = exp_woman_haircare + w2_s31 if w2_s31!=. & w2_s31 >= 0;
			label var exp_woman_haircare "Expenses in hairstyle, hair cuts, etc. for the beneficiary in last 30 days";	
			
		
	* Share of private expenditures in FDJ;
	foreach var in husband_clothes woman_clothes children_clothes adultmen_clothes adultwomen_clothes husband_khat_tabac adultmen_khat_tabac woman_haircare {;
		gen sh_exp_`var' = exp_`var' / exp_total ;
		label var sh_exp_`var' "Share of `var' expenses in total expenditures";
		};
	
***********************************;	
* PMT ;
		merge 1:1 id8 using "$path\data_original\pmt.dta";
				assert _merge==3;
				drop _merge;
	
	* we classify the sample by EDAM's quintiles;
	gen quint_pmtedam = .;
		replace quint_pmtedam = 1 if pmt<57632;
		replace quint_pmtedam = 2 if pmt>=57632 & pmt<100239;
		replace quint_pmtedam = 3 if pmt>=100239 & pmt<164234;
		replace quint_pmtedam = 45 if pmt>=164234 & pmt<278562;
		replace quint_pmtedam = 45 if pmt>=278562 & pmt!=.;
		
		tab quint_pmtedam;
		label var quint_pmtedam "PMT quintiles from EDAM survey - all sample";
	
	
	gen quint_pmtedam_urban = .;
		replace quint_pmtedam_urban = 1 if pmt<103003;
		replace quint_pmtedam_urban = 2 if pmt>=103003 & pmt<156755;
		replace quint_pmtedam_urban = 3 if pmt>=156755 & pmt<223106;
		replace quint_pmtedam_urban = 45 if pmt>=223106 & pmt<345841;
		replace quint_pmtedam_urban = 45 if pmt>=345841 & pmt!=.;
		
		tab quint_pmtedam_urban;
		label var quint_pmtedam_urban "PMT quintiles from EDAM survey - urban sample";
		
	* Above and below the median pmt;
		gen pmt_upper50 = 0 if pmt!=.;
			sum pmt, detail;
			replace pmt_upper50 = 1 if pmt > r(p50) & pmt!=.;
			sum pmt_upper50;	
		
		label var pmt_upper50 "1 if household above the median pmt score";
		
		
***********************;
* Labor Supply;

* WOMEN;

	*** Employment;
	
	* Employment PER DAY (temp);
	
	* Employed at all;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_`day'=0 if w`week'_f1`day'_0!=.;
			lab var w`week'w_employed_`day' "Employed week `week', day `day'";
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_`day'=1 if w`week'_f1`day'_`mult'>0 & w`week'_f1`day'_`mult'<=9 & w`week'_f1`day'_`mult' != .;
			};
			};
		* Generating missing dummy;
		gen w`week'_missing= missing(w`week'_f17_0, w`week'_f16_0, w`week'_f15_0, w`week'_f14_0, w`week'_f13_0, w`week'_f12_0, w`week'_f11_0);
			replace w`week'_missing=1 if w`week'_f17_0==0 & w`week'_f16_0==0 & w`week'_f15_0==0 & w`week'_f14_0==0 & w`week'_f13_0==0 & w`week'_f12_0==0 & w`week'_f11_0==0 & (w`week'_fs0==1 | w`week'_fs0==.) /* correcting for inconsistent answers */;  
			};

	* Employed in day work;
		* We include day work + paid apprenticeship;
		
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_daywork_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_daywork_`day'=1 if w`week'_f1`day'_`mult'==6 | w`week'_f1`day'_`mult'==8;
			};
			};
			};
	
	* Salaried;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_salaried_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_salaried_`day'=1 if w`week'_f1`day'_`mult'==4 | w`week'_f1`day'_`mult'==5;
			};
			};
			};
			
	* Self-employed;
		* We include also people working in a self-employment activity of a hh member;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_selfempl_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_selfempl_`day'=1 if w`week'_f1`day'_`mult'==1 | w`week'_f1`day'_`mult'==3 | w`week'_f1`day'_`mult'==2;
			};
			};
			};	
	
	* Government works;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_gw_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_gw_`day'=1 if w`week'_f1`day'_`mult'==7;
			};
			};
			};	

	* HIMO;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_himo_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_himo_`day'=1 if w`week'_f1`day'_`mult'==7 & w`week'_f1`day'_himo==1;
			};
			};
			};	
			
						
	* Other employement;
		* Only unpaid apprenticeship ;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'w_employed_other_`day'=0 if w`week'_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'w_employed_other_`day'=1 if w`week'_f1`day'_`mult'==9;
			};
			};
			};	

			
* Employment per week: number of days and dummy for each type of employment;

	foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other {;
	forval week=1/3 {;
		egen w`week'w_`x'_ndays=rsum(w`week'w_`x'_1-w`week'w_`x'_7);
			replace w`week'w_`x'_ndays = . if w`week'_missing==1;
			label var w`week'w_`x'_ndays "Number of days woman was `x' in week `week'";
			
		gen w`week'w_`x' = 0 if w`week'w_`x'_ndays!=.;
			replace w`week'w_`x' = 1 if inrange(w`week'w_`x'_ndays, 1, 7); 
			label var w`week'w_`x' "1 if woman `x' in week `week'";
		
		drop w`week'w_`x'_1-w`week'w_`x'_7;
		};
		};

* Unemployment per week;
	tab1 w*_fs0, m;
	tab1 w*_fs2, m;

forval week=1/3 {;
	gen w`week'w_unemployed=.;
		replace w`week'w_unemployed=1 if w`week'w_employed==0 & w`week'_fs0==2 & w`week'_fs2==1;
		lab var w`week'w_unemployed "1 if woman unemployed in week `week'";
		replace w`week'w_unemployed=0 if w`week'w_employed==1 | (w`week'w_employed==0 & w`week'_fs2==2);
		};

* Inactive per week;
	forval week=1/3 {;
	gen w`week'w_inactive=.;
		replace w`week'w_inactive=1 if w`week'w_employed==0 & w`week'_fs0==2 & w`week'_fs2==2;
		lab var w`week'w_inactive "1 if woman inactive in week `week'";
		replace w`week'w_inactive=0 if w`week'w_employed==1 | w`week'w_unemployed==1;
		};		

			
		
* Average employment & unemployment over 3 weeks: number of days and dummy for each type of employment;

foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other unemployed inactive{;
	egen w123w_mean_`x' = rowmean(w1w_`x' w2w_`x' w3w_`x');
		lab var w123w_mean_`x' "Average woman `x' status: week 1 to 3";
		};

foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other{;
	egen w123w_mean_`x'_n = rowmean(w1w_`x'_ndays w2w_`x'_ndays w3w_`x'_ndays);
		lab var w123w_mean_`x'_n "Average number of days woman was `x': week 1 to 3";
		};		
		

*** Hours worked;
	* Per week;
	forval week=1/3 { /* Looping over weeks */;
			gen w`week'w_hoursworked=0;
			lab var w`week'w_hoursworked "Hours worked by woman in week `week'";
	forval day=1/7 { /* Looping over days */;
			* we topcode hours worked;
			replace w`week'_f3`day'=18 if inrange(w`week'_f3`day',18,24);
			replace w`week'w_hoursworked = w`week'w_hoursworked + w`week'_f3`day' if w`week'_f3`day' > 0 & w`week'_f3`day'!=. ;
			};
			egen w`week'_missing_hours=rowmiss(w`week'_f3*);
			replace w`week'w_hoursworked = . if w`week'w_hoursworked==0 & (w`week'_missing == 1 | (w`week'_missing_hours==7 & w`week'w_employed==1));
			};
			
			sum w1w_hoursworked w2w_hoursworked w3w_hoursworked;
			tab w1w_hoursworked w1w_employed, miss;
			tab w2w_hoursworked w2w_employed, miss;
			tab w3w_hoursworked w3w_employed, miss;
			drop w1_missing_hours w2_missing_hours w3_missing_hours;
	
	* Average over 3 weeks;
		egen w123w_mean_hoursworked = rowmean(w1w_hoursworked w2w_hoursworked w3w_hoursworked);
			lab var w123w_mean_hoursworked "Average hours worked by woman over week 1 to 3";
			
*** Remuneration;			
		* missing stay 0 until the final labor income variable is created;
		
		* Remuneration daywork declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'w_pay1 = 0;
				lab var w`week'w_pay1 "Pay per day woman week `week'";
			forval day=1/7 { /* Looping over days */;
				replace w`week'w_pay1 = w`week'w_pay1 + w`week'_f4`day'_fdj if w`week'_f4`day'_fdj>0 & w`week'_f4`day'_fdj!=. ;
				recode w`week'_f4`day'_fdj (-77=.) (-88=.) (-99=.);
				};
				egen w`week'w_missing_pay1=rowmiss(w`week'_f4*_fdj);
					replace w`week'w_missing_pay1=0 if inrange(w`week'w_missing_pay1, 1, 6);
					recode w`week'w_missing_pay1 (7=1); 
				};
	
		* Self-employment activity: income over past 7 days;
			forval week=1/3 {;
				gen w`week'w_pay2=0;
					replace w`week'w_pay2 = w`week'_f6 if w`week'_f6 > 0 & w`week'_f6!=.;
					lab var w`week'w_pay2 "Pay self-empl week `week' (7 days)";
					recode w`week'_f6 (-77=.) (-88=.) (-99=.);
					egen w`week'w_missing_pay2=rowmiss(w`week'_f6);
					};
					sum w*w_pay2;
								
		* Self-employment activities: income over past 30 days scaled to 7 days;
			forval week=1/3 {;
				gen w`week'w_pay3=0;
					replace w`week'w_pay3 = w`week'_f7 if w`week'_f7>0 & w`week'_f7!=.;
					replace w`week'w_pay3 = w`week'w_pay3 / 4.35;
					lab var w`week'w_pay3 "Pay self-empl week `week' (30 days)";
					recode w`week'_f7 (-77=.) (-88=.) (-99=.);
					egen w`week'w_missing_pay3=rowmiss(w`week'_f7);
					};
					sum w*w_pay3;
				
		* Salaried Pay; 
			forval week=1/3 {;
				gen w`week'w_pay4=0;
					replace w`week'w_pay4 = w`week'_f9 if w`week'_f9>0 & w`week'_f9!=.;
					replace w`week'w_pay4= w`week'w_pay4 / 2 if w`week'_f8==2;
					replace w`week'w_pay4 = w`week'w_pay4 / 4.35 if w`week'_f8==3;
					* f8 = 4 is just a check - no data on daily income here;
					lab var w`week'w_pay4 "Pay salaried week `week' (month, bi-monthy or weekly)";
					recode w`week'_f9 (-77=.) (-88=.) (-99=.);
					egen w`week'w_missing_pay4=rowmiss(w`week'_f9);
					};
					sum w*w_pay4;
		
		
		** Labor income per week;
		* Note: we use pay1, pay3 and pay4 to get overall renumeration per week. For self employment, income over the past month (scaled to 7 days) is used;
		
		* missing;
		foreach week in w1 w2 w3 {;
			egen `week'w_missing_pay = rowtotal(`week'w_missing_pay1 `week'w_missing_pay3 `week'w_missing_pay4);
				recode `week'w_missing_pay (2=0) (1=0) (3=1); 
				};
			
		* Total labor income per week;
		foreach week in w1 w2 w3 {;
			egen `week'w_remun = rowtotal(`week'w_pay1 `week'w_pay3 `week'w_pay4);
			replace `week'w_remun = . if `week'w_missing_pay==1 & (`week'w_employed==1 | (`week'w_employed==. & `week'w_remun==0));
			label var `week'w_remun "Remuneration woman `week'"; 
			
			replace `week'w_pay1=. if `week'w_remun==.;
			replace `week'w_pay2=. if `week'w_remun==.;
			replace `week'w_pay3=. if `week'w_remun==.;
			replace `week'w_pay4=. if `week'w_remun==.;
			
			sum `week'w_pay1 `week'w_pay3 `week'w_pay4 `week'w_remun;
			};
			
		
		* Average of TOTAL labor income over 3 weeks;
		egen w123w_mean_remun = rowmean(w1w_remun w2w_remun w3w_remun);
			lab var w123w_mean_remun "Average remuneration woman over week 1 to 3";
			
			sum w1w_remun w2w_remun w3w_remun w123w_mean_remun; 	
			drop w1w_pay1- w3w_missing_pay;
		
		******************************;
		* Income by TYPE of activity;
			* TBC: there are errors in the employment variables: w1w_employed_daywork, 	w1w_employed_gw, w1w_employed_himo, w1w_employed_other, etc;

		
			* Self-employment declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'w_self = 0;
				lab var w`week'w_self "Woman's income from self-employment week `week'";
				gen w`week'w_hours_self = 0;
				lab var w`week'w_hours_self "Woman's hours in self-employment week `week'";
			
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'w_self = w`week'w_self + w`week'_f4`day'_fdj if w`week'_f4`day'_fdj>0 & w`week'_f4`day'_fdj!=. & inrange(w`week'_f1`day'_`mult', 1, 3) & (w`week'_f7 == 0 | w`week'_f7==.);
				replace w`week'w_hours_self = w`week'w_hours_self + w`week'_f3`day' if w`week'_f3`day' > 0 & w`week'_f3`day'!=. & inrange(w`week'_f1`day'_`mult', 1, 3);
				};
				};
				replace w`week'w_self = w`week'w_self + (w`week'_f7 / 4.35) if w`week'_f7 > 0 & w`week'_f7 !=. & w`week'w_employed_selfempl==1 & w`week'w_self==0;
				};
			
			* Salaried declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'w_salaried = 0;
					replace w`week'w_salaried = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_salaried == 1;
					replace w`week'w_salaried = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_salaried == 1;
					replace w`week'w_salaried = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_salaried == 1;
		
					lab var w`week'w_salaried "Woman's income from salary week `week'";
				
				gen w`week'w_hours_salaried = 0;
					lab var w`week'w_hours_salaried "Woman's hours in salary week `week'";
					
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'w_hours_salaried = w`week'w_hours_salaried + w`week'_f3`day' if w`week'_f3`day' > 0 & w`week'_f3`day'!=. & inrange(w`week'_f1`day'_`mult', 4, 5);
				};
				};
				};
		
			* Day work declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'w_daywork = 0;
				lab var w`week'w_daywork "Woman's income from daywork week `week'";
				
				gen w`week'w_hours_daywork = 0;
				lab var w`week'w_hours_daywork "Woman's hours in daywork week `week'";
			
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'w_daywork = w`week'w_daywork + w`week'_f4`day'_fdj if w`week'_f4`day'_fdj>0 & w`week'_f4`day'_fdj!=. & (w`week'_f1`day'_`mult'==6 | w`week'_f1`day'_`mult'==8);
				replace w`week'w_hours_daywork = w`week'w_hours_daywork + w`week'_f3`day' if w`week'_f3`day' > 0 & w`week'_f3`day'!=. & (w`week'_f1`day'_`mult'==6 | w`week'_f1`day'_`mult'==8);
				};
				};
				replace w`week'w_daywork = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_daywork == 1 & w`week'w_daywork==0 & w`week'w_employed_salaried == 0 & w`week'w_employed_himo == 0;
				replace w`week'w_daywork = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_daywork == 1 & w`week'w_daywork==0 & w`week'w_employed_salaried == 0 & w`week'w_employed_himo == 0;
				replace w`week'w_daywork = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_daywork == 1 & w`week'w_daywork==0 & w`week'w_employed_salaried == 0 & w`week'w_employed_himo == 0;
				};
		
			* Public Works declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'w_himo = 0;
				lab var w`week'w_himo "Woman's income from public works week `week'";
				
				gen w`week'w_hours_himo = 0;
				lab var w`week'w_hours_himo "Woman's hours in public works week `week'";
			
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'w_himo = w`week'w_himo + w`week'_f4`day'_fdj if w`week'_f4`day'_fdj>0 & w`week'_f4`day'_fdj!=. & w`week'_f1`day'_`mult'==7 & w`week'_f1`day'_himo==1;
				replace w`week'w_hours_himo = w`week'w_hours_himo + w`week'_f3`day' if w`week'_f3`day' > 0 & w`week'_f3`day'!=. & w`week'_f1`day'_`mult'==7 & w`week'_f1`day'_himo==1;
				};
				};
				
				replace w`week'w_himo = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_himo == 1 & w`week'w_himo==0;
				replace w`week'w_himo = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_himo ==1 & w`week'w_himo==0;
				replace w`week'w_himo = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_himo == 1 & w`week'w_himo==0;
				};
			
			*************;
			* Corrections;
				* Himo and self-employment;
				foreach id in 12095 19811 19909 20567 21526 22578 23284 {;
				foreach week in 1 {;
					replace w`week'w_himo = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_himo == 1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_himo ==1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_himo == 1 & id8 == `id';
					};
					};

				replace w1w_himo = . if id8==23284;
				
				foreach id in 12095 13633 19811 20567 {;
				foreach week in 2 {;
					replace w`week'w_himo = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_himo == 1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_himo ==1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_himo == 1 & id8 == `id';
					};
					};
				
				replace w2w_himo = . if id8 ==19909;
				
				foreach id in 12095 13633 19811 19909 20567 21303 21499 {;
				foreach week in 3 {;
					replace w`week'w_himo = w`week'_f9 			if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==1 & w`week'w_employed_himo == 1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 2 		if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==2 & w`week'w_employed_himo ==1 & id8 == `id';
					replace w`week'w_himo = w`week'_f9 / 4.35 	if w`week'_f9>0 & w`week'_f9!=. & w`week'_f8==3 & w`week'w_employed_himo == 1 & id8 == `id';
					};
					};

				* HIMO & Salaried;
				replace w1w_salaried =. if id8==20301 & id8 == 21628;
				replace w3w_salaried =. if id8== 19813 & id8 == 19942 & id8 == 20333 & id8 == 21293;

				
				* HIMO and Day work or Day Work and Self employed;
					foreach id in 20331 20612 20741 22472 22983 {;
						replace w1w_daywork = . if id8 == `id';
						};
				
					foreach id in 12640 20567 21515 20591 21499 {;
						replace w2w_daywork=. if id8 == `id';
						};
					
					foreach id in 12675 20269 22671 23199 23208 13246 20305 {;
						replace w3w_daywork=. if id8 == `id';
						};
					
	* Average of labor income BY TYPE over 3 weeks, conditional on the activity type;
		foreach type in self salaried daywork himo {;
			recode w1w_`type' w2w_`type' w3w_`type' (0=.);
			recode w1w_hours_`type' w2w_hours_`type' w3w_hours_`type' (0=.);
	
			egen w123w_inc_`type' = rowmean(w1w_`type' w2w_`type' w3w_`type');
				lab var w123w_inc_`type' "Average woman remuneration from `type' over week 1 to 3 (cond)";
			
			egen w123w_hours_`type' = rowmean(w1w_hours_`type' w2w_hours_`type' w3w_hours_`type');
				lab var w123w_hours_`type' "Average hours worked by woman in `type' over week 1 to 3 (cond)";
			
			};
				
				
				
				#delimit;
				sum w123w_inc_self w123w_inc_salaried w123w_inc_daywork w123w_inc_himo if treatment==1;
				sum w123w_hours_self w123w_hours_salaried w123w_hours_daywork w123w_hours_himo if treatment==1;
				
				sum w123w_inc_self w123w_inc_salaried w123w_inc_daywork w123w_inc_himo if treatment==1, d;
				sum w123w_hours_self w123w_hours_salaried w123w_hours_daywork w123w_hours_himo if treatment==1, d;
				
				* Stats for the paper;
				sum w123w_inc_self w123w_inc_salaried w123w_inc_daywork w123w_inc_himo if treatment==0;
				sum w123w_hours_self w123w_hours_salaried w123w_hours_daywork w123w_hours_himo if treatment==0;
				
				sum w123w_inc_self w123w_inc_salaried w123w_inc_daywork w123w_inc_himo if treatment==0, d;
				sum w123w_hours_self w123w_hours_salaried w123w_hours_daywork w123w_hours_himo if treatment==0, d;
				
						
		************************************************;
		* Type self-employment activity;
			
			foreach act in street shop transp hand serv other {;
				gen w_self_`act' = 0 if w123w_mean_employed!=.;
				};
			
				foreach week in 1 2 3{;
					replace w_self_street =  w_self_street + 1 if w`week'_f17_actprop == 1;
					replace w_self_shop = w_self_shop + 1 if w`week'_f17_actprop == 2;
					replace w_self_transp = w_self_transp + 1 if w`week'_f17_actprop == 3;
					replace w_self_hand = w_self_hand + 1 if w`week'_f17_actprop == 4;
					replace w_self_serv = w_self_serv + 1 if w`week'_f17_actprop == 5;
					replace w_self_other = w_self_other + 1 if w`week'_f17_actprop == 6;
					};
		
				* We correct misreporting;
				replace w_self_street = 1 if w_self_street >0 & w_self_shop >0 & (w_self_street > w_self_shop);
				replace w_self_shop = 0 if w_self_street >0 & w_self_shop >0 & (w_self_street > w_self_shop);
		
				replace w_self_street = 0 if w_self_street >0 & w_self_shop >0 & (w_self_street < w_self_shop);
				replace w_self_shop = 1 if w_self_street >0 & w_self_shop >0 & (w_self_street < w_self_shop);
		
				recode w_self_street w_self_shop w_self_transp w_self_hand w_self_serv w_self_other (3=1) (2=1);
				
				sum w_self_street w_self_shop w_self_transp w_self_hand w_self_serv w_self_other; 
		
		
		
		** Reasons woman has not worked over the past week;
			* Not conditional;
		
			foreach week in w1 w2 w3 {;
				foreach reason in cannotfind family looking other {;
					gen `week'w_reasnowork_`reason' = 0 if `week'w_employed!=.;
					};
					
					label var `week'w_reasnowork_cannotfind "Woman did not work bc could not find a job `week'";
					label var `week'w_reasnowork_family  "Woman did not work due to family obligations `week'";
					label var `week'w_reasnowork_looking "Woman did not work bc work just finished and looking for a job `week'";
					label var `week'w_reasnowork_other "Woman did not work due to another reason `week'";
						
				foreach i of numlist 0/11 {;
					replace `week'w_reasnowork_cannotfind = 1 if `week'w_employed==0 & `week'_fs1_`i'==1 ;
					replace `week'w_reasnowork_family = 1 if `week'w_employed==0 & `week'_fs1_`i'==4;
					replace `week'w_reasnowork_looking = 1 if `week'w_employed==0 & `week'_fs1_`i'==9;
					replace `week'w_reasnowork_other = 1 if `week'w_employed==0 & (`week'_fs1_`i'==2 | `week'_fs1_`i'==3 | `week'_fs1_`i'==5 | `week'_fs1_`i'==6 | `week'_fs1_`i'==7 | `week'_fs1_`i'==8 | `week'_fs1_`i'==10 | `week'_fs1_`i'==11);
					* we correct cases where women say they "just finished a job and are looking for a new one" but then they say they did not take concrete to look for a job;  
					replace `week'w_reasnowork_other = 1 if `week'w_reasnowork_looking ==1 & `week'w_employed==0 & `week'w_unemployed==0;
					replace `week'w_reasnowork_looking = 0 if `week'w_reasnowork_looking ==1 & `week'w_employed==0 & `week'w_unemployed==0;
					};
				};
			
						
				egen w123w_reasnowork_cannotfind = rowmean (w1w_reasnowork_cannotfind w2w_reasnowork_cannotfind w3w_reasnowork_cannotfind);
					label var w123w_reasnowork_cannotfind "Woman did not work bc could not find a job (average week 1 to 3)";
				
				egen w123w_reasnowork_family = rowmean (w1w_reasnowork_family w2w_reasnowork_family w3w_reasnowork_family);
					label var w123w_reasnowork_family "Woman did not work due to family obligations (average week 1 to 3)";
				
				egen w123w_reasnowork_looking = rowmean (w1w_reasnowork_looking w2w_reasnowork_looking w3w_reasnowork_looking);
					label var w123w_reasnowork_looking "Woman did not work bc work just finished and looking for a job (average week 1 to 3)";
		
				egen w123w_reasnowork_other = rowmean (w1w_reasnowork_other w2w_reasnowork_other w3w_reasnowork_other);
					label var w123w_reasnowork_other "Woman did not work due to another reason(average week 1 to 3)";

************;			
* Husband;
************;
	* Employment PER DAY (temp);
	* Employed at all;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_`day'=0 if w`week'm_f1`day'_0!=.;
			lab var w`week'm_employed_`day' "Employed week `week', day `day'";
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_`day'=1 if w`week'm_f1`day'_`mult'>0 & w`week'm_f1`day'_`mult'<=9 & w`week'm_f1`day'_`mult' != .;
			};
			};
		* Generating missing dummy;
		gen w`week'm_missing= missing(w`week'm_f17_0, w`week'm_f16_0, w`week'm_f15_0, w`week'm_f14_0, w`week'm_f13_0, w`week'm_f12_0, w`week'm_f11_0);
			replace w`week'm_missing=1 if w`week'm_f17_0==0 & w`week'm_f16_0==0 & w`week'm_f15_0==0 & w`week'm_f14_0==0 & w`week'm_f13_0==0 & w`week'm_f12_0==0 & w`week'm_f11_0==0 & (w`week'm_fs0==1 | w`week'm_fs0==.) /* correcting for inconsistent answers */;  
			};

	* Employed in day work;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_daywork_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_daywork_`day'=1 if (w`week'm_f1`day'_`mult'==6 | w`week'm_f1`day'_`mult'==8);
			};
			};
			};
	
	* Salaried;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_salaried_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_salaried_`day'=1 if w`week'm_f1`day'_`mult'==4 | w`week'm_f1`day'_`mult'==5;
			};
			};
			};
			
	* Self-employed;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_selfempl_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_selfempl_`day'=1 if w`week'm_f1`day'_`mult'==1 | w`week'm_f1`day'_`mult'==3 | w`week'm_f1`day'_`mult'==2;
			};
			};
			};	
	
	* Government works;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_gw_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_gw_`day'=1 if w`week'm_f1`day'_`mult'==7;
			};
			};
			};	

	* HIMO;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_himo_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_himo_`day'=1 if w`week'm_f1`day'_`mult'==7 & w`week'm_f1`day'_himo==1;
			};
			};
			};	
			
	* Other employement;
		* Only unpaid apprenticeship;
		forval week=1/3 { /* Looping over weeks */;	
		forval day=1/7 { /* Looping over days */;
			gen w`week'm_employed_other_`day'=0 if w`week'm_f1`day'_0!=.;
			forval mult=0/8 { /* Looping over multiple responses */;
			replace w`week'm_employed_other_`day'=1 if w`week'm_f1`day'_`mult'==9;
			};
			};
			};	

			
* Employment per week: number of days and dummy for each type of employment;

	foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other {;
	forval week=1/3 {;
		egen w`week'm_`x'_ndays=rsum(w`week'm_`x'_1-w`week'm_`x'_7);
			replace w`week'm_`x'_ndays = . if w`week'm_missing==1;
			label var w`week'm_`x'_ndays "Number of days husband was `x' in week `week'";
			
		gen w`week'm_`x' = 0 if w`week'm_`x'_ndays!=.;
			replace w`week'm_`x' = 1 if inrange(w`week'm_`x'_ndays, 1, 7); 
			label var w`week'm_`x' "1 if husband `x' in week `week'";
		
		drop w`week'm_`x'_1-w`week'm_`x'_7;
		};
		};

* Unemployment per week;
	tab1 w*_fs0, m;
	tab1 w*_fs2, m;

forval week=1/3 {;
	gen w`week'm_unemployed=.;
		replace w`week'm_unemployed=1 if w`week'm_employed==0 & w`week'm_fs0==2 & w`week'm_fs2==1;
		lab var w`week'm_unemployed "1 if husband unemployed in week `week'";
		replace w`week'm_unemployed=0 if w`week'm_employed==1 | (w`week'm_employed==0 & w`week'm_fs2==2);
		};

* Inactive per week;
	forval week=1/3 {;
	gen w`week'm_inactive=.;
		replace w`week'm_inactive=1 if w`week'm_employed==0 & w`week'm_fs0==2 & w`week'm_fs2==2;
		lab var w`week'm_inactive "1 if husband inactive in week `week'";
		replace w`week'm_inactive=0 if w`week'm_employed==1 | w`week'm_unemployed==1;
		};				
		
* Average employment & unemployment over 3 weeks: number of days and dummy for each type of employment;

foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other unemployed inactive{;
	egen w123m_mean_`x' = rowmean(w1m_`x' w2m_`x' w3m_`x');
		lab var w123m_mean_`x' "Average husband `x' status: week 1 to 3";
		};

foreach x in employed employed_daywork employed_salaried employed_selfempl employed_gw employed_himo employed_other {;
	egen w123m_mean_`x'_n = rowmean(w1m_`x'_ndays w2m_`x'_ndays w3m_`x'_ndays);
		lab var w123m_mean_`x'_n "Average number of days husband was `x': week 1 to 3";
		};		

		
*** Hours worked;
	* Per week;
	forval week=1/3 { /* Looping over weeks */;
			gen w`week'm_hoursworked=0;
			lab var w`week'm_hoursworked "Hours worked by woman in week `week'";
	forval day=1/7 { /* Looping over days */;
			* we topcode hours worked at 18 hours;
			replace w`week'm_f3`day' = 18 if inrange(w`week'm_f3`day', 18,24); 
			replace w`week'm_hoursworked = w`week'm_hoursworked + w`week'm_f3`day' if w`week'm_f3`day' > 0 & w`week'm_f3`day'!=. ;
			};
			egen w`week'm_missing_hours=rowmiss(w`week'm_f3*);
			replace w`week'm_hoursworked = . if w`week'm_hoursworked==0 & (w`week'm_missing == 1 | (w`week'm_missing_hours==7 & w`week'm_employed==1));
			};
			
			sum w1m_hoursworked w2m_hoursworked w3m_hoursworked;
			tab w1m_hoursworked w1m_employed, miss;
			tab w2m_hoursworked w2m_employed, miss;
			tab w3m_hoursworked w3m_employed, miss;
			drop w1m_missing_hours w2m_missing_hours w3m_missing_hours;
	
	* Average over 3 weeks;
		egen w123m_mean_hoursworked = rowmean(w1m_hoursworked w2m_hoursworked w3m_hoursworked);
			lab var w123m_mean_hoursworked "Average hours worked by husband over week 1 to 3";
			
*** Remuneration;			
		* missing stay 0 until the final labor income variable is created;
		
		* Remuneration daywork declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'm_pay1 = 0;
				lab var w`week'm_pay1 "Pay per day woman week `week'";
			forval day=1/7 { /* Looping over days */;
				replace w`week'm_pay1 = w`week'm_pay1 + w`week'm_f4`day'_fdj if w`week'm_f4`day'_fdj>0 & w`week'm_f4`day'_fdj!=. ;
				recode w`week'm_f4`day'_fdj (-77=.) (-88=.) (-99=.);
				};
				egen w`week'm_missing_pay1=rowmiss(w`week'm_f4*_fdj);
					replace w`week'm_missing_pay1=0 if inrange(w`week'm_missing_pay1, 1, 6);
					recode w`week'm_missing_pay1 (7=1); 
				};
	
		* Self-employment activity: income over past 7 days;
			forval week=1/3 {;
				gen w`week'm_pay2=0;
					replace w`week'm_pay2 = w`week'm_f6 if w`week'm_f6 > 0 & w`week'm_f6!=.;
					lab var w`week'm_pay2 "Pay self-empl week `week' (7 days)";
					recode w`week'm_f6 (-77=.) (-88=.) (-99=.);
					egen w`week'm_missing_pay2=rowmiss(w`week'm_f6);
					};
					sum w*m_pay2;
								
		* Self-employment activities: income over past 30 days scaled to 7 days;
			forval week=1/3 {;
				gen w`week'm_pay3=0;
					replace w`week'm_pay3 = w`week'm_f7 if w`week'm_f7>0 & w`week'm_f7!=.;
					replace w`week'm_pay3 = w`week'm_pay3 / 4.35;
					lab var w`week'm_pay3 "Pay self-empl week `week' (30 days)";
					recode w`week'm_f7 (-77=.) (-88=.) (-99=.);
					egen w`week'm_missing_pay3=rowmiss(w`week'_f7);
					};
					sum w*m_pay3;
				
		* Salaried Pay; 
			forval week=1/3 {;
				gen w`week'm_pay4=0;
					replace w`week'm_pay4 = w`week'm_f9 if w`week'm_f9>0 & w`week'm_f9!=.;
					replace w`week'm_pay4= w`week'm_pay4 / 2 if w`week'm_f8==2;
					replace w`week'm_pay4 = w`week'm_pay4 / 4.35 if w`week'm_f8==3;
					* f8 = 4 is just a check - no data on daily income here;
					lab var w`week'm_pay4 "Pay salaried week `week' (month, bi-monthy or weekly)";
					recode w`week'm_f9 (-77=.) (-88=.) (-99=.);
					egen w`week'm_missing_pay4=rowmiss(w`week'_f9);
					};
					sum w*m_pay4;
		
		
		** Labor income per week;
		* Note: Now going to use pay1, pay2 and pay4 to get overall renumeration per week. For self employment, income over the past month (scaled to 7 days) is used;
		
		* missing;
		foreach week in w1 w2 w3 {;
			egen `week'm_missing_pay = rowtotal(`week'm_missing_pay1 `week'm_missing_pay3 `week'm_missing_pay4);
				recode `week'm_missing_pay (2=0) (1=0) (3=1); 
				};
			
		* total labor income per week ;
		foreach week in w1 w2 w3 {;
			egen `week'm_remun = rowtotal(`week'm_pay1 `week'm_pay3 `week'm_pay4);
			replace `week'm_remun = . if `week'm_missing_pay==1 & (`week'm_employed==1 | (`week'm_employed==. & `week'm_remun==0));
			label var `week'm_remun "Remuneration woman `week'"; 
			
			replace `week'm_pay1=. if `week'm_remun==.;
			replace `week'm_pay2=. if `week'm_remun==.;
			replace `week'm_pay3=. if `week'm_remun==.;
			replace `week'm_pay4=. if `week'm_remun==.;
			
			sum `week'm_pay1 `week'm_pay3 `week'm_pay4 `week'm_remun;
			};
										
			drop w1m_pay1- w3m_missing_pay;
			
		* average labor income over 3 weeks;
		egen w123m_mean_remun = rowmean(w1m_remun w2m_remun w3m_remun);
			lab var w123m_mean_remun "Average remuneration husband over week 1 to 3";
		
			sum w1m_remun w2m_remun w3m_remun w123m_mean_remun; 	
		
		******************************;
		* Income by TYPE of activity;
			* TBC: there are errors in the employment variables: w1m_employed_daywork, 	w1m_employed_gw, w1m_employed_himo, w1m_employed_other, etc;

			
			* Self-employment declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'm_self = 0;
				lab var w`week'm_self "Man's income from self-employment week `week'";
				gen w`week'm_hours_self=0;
				lab var w`week'm_hours_self "Man's hours in self-employment week `week'";
			
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'm_self = w`week'm_self + w`week'm_f4`day'_fdj if w`week'm_f4`day'_fdj>0 & w`week'm_f4`day'_fdj!=. & inrange(w`week'm_f1`day'_`mult', 1, 3) & (w`week'm_f7 == 0 | w`week'm_f7==.);
				replace w`week'm_hours_self =  w`week'm_hours_self + w`week'm_f3`day' if w`week'm_f3`day' > 0 & w`week'm_f3`day'!=. & inrange(w`week'm_f1`day'_`mult', 1, 3);
				};
				};
				replace w`week'm_self = w`week'm_self + (w`week'm_f7 / 4.35) if w`week'm_f7 > 0 & w`week'm_f7 !=. & w`week'm_employed_selfempl==1 & w`week'm_self==0;
				};
			
			* Salaried declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'm_salaried = 0;
					replace w`week'm_salaried = w`week'm_f9 			if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==1 & w`week'm_employed_salaried == 1;
					replace w`week'm_salaried = w`week'm_f9 / 2 		if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==2 & w`week'm_employed_salaried == 1;
					replace w`week'm_salaried = w`week'm_f9 / 4.35 	if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==3 & w`week'm_employed_salaried == 1;
		
					lab var w`week'm_salaried "Man's income from salary week `week'";
					
				gen w`week'm_hours_salaried=0;
				lab var w`week'm_hours_salaried "Man's hours in salaried work week `week'";	
				
				forval day=1/7 { /* Looping over days */;
				forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'm_hours_salaried =  w`week'm_hours_salaried + w`week'm_f3`day' if w`week'm_f3`day' > 0 & w`week'm_f3`day'!=. & inrange(w`week'm_f1`day'_`mult', 4, 5);
				};
				};
				};
				
			* Day work declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'm_daywork = 0;
				lab var w`week'm_daywork "Man's income from daywork week `week'";
				gen w`week'm_hours_daywork = 0;
				lab var w`week'm_hours_daywork "Man's hours in daywork week `week'";
				
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'm_daywork = w`week'm_daywork + w`week'm_f4`day'_fdj if w`week'm_f4`day'_fdj>0 & w`week'm_f4`day'_fdj!=. & (w`week'm_f1`day'_`mult'==6 | w`week'm_f1`day'_`mult'==8);
				replace w`week'm_hours_daywork =  w`week'm_hours_daywork + w`week'm_f3`day' if w`week'm_f3`day' > 0 & w`week'm_f3`day'!=. & (w`week'm_f1`day'_`mult'==6 | w`week'm_f1`day'_`mult'==8);
				};
				replace w`week'm_daywork = w`week'm_f9 			if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==1 & w`week'm_employed_daywork == 1 & w`week'm_daywork==0;
				replace w`week'm_daywork = w`week'm_f9 / 2 		if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==2 & w`week'm_employed_daywork == 1 & w`week'm_daywork==0;
				replace w`week'm_daywork = w`week'm_f9 / 4.35 	if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==3 & w`week'm_employed_daywork == 1 & w`week'm_daywork==0;
							
				};
				};
		
			* Public Works declared in diary;
			forval week=1/3 { /* Looping over weeks */;
				gen w`week'm_himo = 0;
				lab var w`week'm_himo "Man's income from public works week `week'";
				gen w`week'm_hours_himo = 0;
				lab var w`week'm_hours_himo "Man's hours from public works week `week'";
			
			forval day=1/7 { /* Looping over days */;
			forval mult=0/8 { /* Looping over multiple responses */;
				replace w`week'm_himo = w`week'm_himo + w`week'm_f4`day'_fdj if w`week'm_f4`day'_fdj>0 & w`week'm_f4`day'_fdj!=. & w`week'm_f1`day'_`mult'==7 & w`week'm_f1`day'_himo==1;
				replace w`week'm_hours_himo =  w`week'm_hours_himo + w`week'm_f3`day' if w`week'm_f3`day' > 0 & w`week'm_f3`day'!=. & w`week'm_f1`day'_`mult'==7 & w`week'm_f1`day'_himo==1;
				};
				};
				
				replace w`week'm_himo = w`week'm_f9 			if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==1 & w`week'm_employed_himo == 1 & w`week'm_himo==0;
				replace w`week'm_himo = w`week'm_f9 / 2 		if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==2 & w`week'm_employed_himo ==1 & w`week'm_himo==0;
				replace w`week'm_himo = w`week'm_f9 / 4.35 	if w`week'm_f9>0 & w`week'm_f9!=. & w`week'm_f8==3 & w`week'm_employed_himo == 1 & w`week'm_himo==0;
				};
				
						
	* Average of labor income BY TYPE over 3 weeks, conditional on the activity type;
		foreach type in self salaried daywork himo {;
			recode w1m_`type' w2m_`type' w3m_`type' (0=.);
			recode w1m_hours_`type' w2m_hours_`type' w3m_hours_`type' (0=.);
			
			egen w123m_inc_`type' = rowmean(w1m_`type' w2m_`type' w3m_`type');
				lab var w123m_inc_`type' "Average man remuneration from `type' over week 1 to 3 (cond)";
			
			egen w123m_hours_`type' = rowmean(w1m_hours_`type' w2m_hours_`type' w3m_hours_`type');
				lab var w123m_hours_`type' "Average hours worked by husband in `type' over week 1 to 3 (cond)";
				};
							
				
				sum w123m_inc_self w123m_inc_salaried w123m_inc_daywork w123m_inc_himo if treatment==1;
				sum w123m_hours_self w123m_hours_salaried w123m_hours_daywork w123m_hours_himo if treatment ==1;
				
				sum w123m_inc_self w123m_inc_salaried w123m_inc_daywork w123m_inc_himo if treatment==1, d;
				sum w123m_hours_self w123m_hours_salaried w123m_hours_daywork w123m_hours_himo if treatment ==1, d;
										
				
				* Stats for paper;
				sum w123m_inc_self w123m_inc_salaried w123m_inc_daywork w123m_inc_himo if treatment==0;
				sum w123m_hours_self w123m_hours_salaried w123m_hours_daywork w123m_hours_himo if treatment==0;
				
				sum w123m_inc_self w123m_inc_salaried w123m_inc_daywork w123m_inc_himo if treatment==0, d;
				sum w123m_hours_self w123m_hours_salaried w123m_hours_daywork w123m_hours_himo if treatment==0, d;
				
									
				drop w1m_self- w3m_hours_himo;
			
		
	* TYPE of self-employment activities;
		foreach act in street shop transp hand serv other {;
				gen m_self_`act' = 0;
				};
			
				foreach week in 1 2 3{;
					replace m_self_street =  m_self_street + 1 	if w`week'm_f17_actprop == 1;
					replace m_self_shop = m_self_shop + 1 		if w`week'm_f17_actprop == 2;
					replace m_self_transp = m_self_transp + 1 	if w`week'm_f17_actprop == 3;
					replace m_self_hand = m_self_hand + 1 		if w`week'm_f17_actprop == 4;
					replace m_self_serv = m_self_serv + 1 		if w`week'm_f17_actprop == 5;
					replace m_self_other = m_self_other + 1 	if w`week'm_f17_actprop == 6;
					};
		
				* We correct misreporting;
				replace m_self_street = 1 if m_self_street >0 & m_self_shop >0 & (m_self_street > m_self_shop);
				replace m_self_shop = 0 if m_self_street >0 & m_self_shop >0 & (m_self_street > m_self_shop);
		
				replace m_self_street = 0 if m_self_street >0 & m_self_shop >0 & (m_self_street < m_self_shop);
				replace m_self_shop = 1 if m_self_street >0 & m_self_shop >0 & (m_self_street < m_self_shop);
		
				recode m_self_street m_self_shop m_self_transp m_self_hand m_self_serv m_self_other (3=1) (2=1);
				
				sum m_self_street m_self_shop m_self_transp m_self_hand m_self_serv m_self_other; 
				
				*************************************************;
		* Reasons husband has not worked (not conditional);
						
			foreach week in w1 w2 w3 {;
				foreach reason in cannotfind looking other {;
					gen `week'm_reasnowork_`reason' = 0 if `week'm_employed!=.;
					};
					
					label var `week'm_reasnowork_cannotfind "Husband did not work bc could not find a job `week'";
					label var `week'm_reasnowork_looking "Husband did not work bc work just finished and looking for a job `week'";
					label var `week'm_reasnowork_other "Husband did not work due to another reason `week'";
						
				foreach i of numlist 0/11 {;
					replace `week'm_reasnowork_cannotfind = 1 if `week'm_employed==0 & `week'm_fs1_`i'==1 ;
					replace `week'm_reasnowork_looking = 1 if `week'm_employed==0 & `week'm_fs1_`i'==9;
					replace `week'm_reasnowork_other = 1 if `week'm_employed==0 & (`week'm_fs1_`i'==2 | `week'm_fs1_`i'==3 | `week'm_fs1_`i'==4 | `week'm_fs1_`i'==5 | `week'm_fs1_`i'==6 | `week'm_fs1_`i'==7 | `week'm_fs1_`i'==8 | `week'm_fs1_`i'==10 | `week'm_fs1_`i'==11);
					* we correct cases where men are inactive but say they are looking for a job;
					replace `week'm_reasnowork_other = 1 if `week'w_reasnowork_looking ==1 & `week'w_employed==0 & `week'w_unemployed==0;
					replace `week'm_reasnowork_looking = 0 if `week'w_reasnowork_looking ==1 & `week'w_employed==0 & `week'w_unemployed==0;
					};
			};
			
			egen w123m_reasnowork_cannotfind = rowmean (w1m_reasnowork_cannotfind w2m_reasnowork_cannotfind w3m_reasnowork_cannotfind);
				label var w123m_reasnowork_cannotfind "Husband did not work bc could not find a job (average week 1 to 3)";
							
			egen w123m_reasnowork_looking = rowmean (w1m_reasnowork_looking w2m_reasnowork_looking w3m_reasnowork_looking);
				label var w123m_reasnowork_looking "Husband did not work bc work just finished and looking for a job (average week 1 to 3)";
				
			egen w123m_reasnowork_other = rowmean (w1m_reasnowork_other w2m_reasnowork_other w3m_reasnowork_other);
					label var w123m_reasnowork_other "Husband did not work due to another reason(average week 1 to 3)";
		
			
	
***************************************************;			
* Work from roster: all HH members except the woman;
****************************************************;
* Label variables;
* Time worked;
* Earnings;

#delimit ;
	foreach week in w1 w2 w3 {;
	egen `week'_hhemploymiss = rowmiss(`week'_h1a_*);
		replace `week'_hhemploymiss=0 if `week'_hhemploymiss<17;
		replace `week'_hhemploymiss=1 if `week'_hhemploymiss==17;
		};
		
	* Number of adults;
	foreach week in w1 w2 w3 {;
		gen `week'_nothadults = 0;
		gen `week'_noinfo = 0;
		foreach i of numlist 0/16 {;
			replace `week'_nothadults  = `week'_nothadults  + 1 if ((`week'_h5_`i'>=15 & `week'_h5_`i'!=.) | `week'_h5_`i'<0) & `week'_h1a_`i'==1 /* & `week'_h3_`i'==2 */;
			replace `week'_noinfo  = `week'_noinfo  + 1 if ((`week'_h5_`i'>=15 & `week'_h5_`i'!=.) | `week'_h5_`i'<0) & `week'_h1a_`i'==1 & `week'_h3_`i'==1;
			};
			tab `week'_nothadults `week'_noinfo;
			replace `week'_hhemploymiss = 1 if (`week'_noinfo> 2 & `week'_noinfo!=.) | (`week'_nothadults == 2 & `week'_noinfo==2);
			replace `week'_nothadults = . if `week'_hhemploymiss==1 ;
			replace `week'_nothadults = `week'_nothadults - 1 if `week'_noinfo > 0 ;
			label var `week'_nothadults "Number of adults besides woman beneficiary" ;			
			};
						
						
		* Number of adults who worked;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_worked_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				foreach j of numlist 6/13 {;
					replace `week'oth_worked_`i'  = 1 if `week'_h`j'_`i'==1;
					};
					};		
					};
			
		* Number of adults unemployed;
			/* missing variable */ /*gen w1_h22_16 = .*/;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_unemployed_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
					replace `week'oth_unemployed_`i'  = 1 if `week'_h22_`i'==1;
					};		
					};
	
		* Number of adults inactive;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_inactive_`i' = 0 if `week'_h1a_`i'==1;
					replace `week'oth_inactive_`i'  = 1 if `week'oth_worked_`i'==0 & `week'oth_unemployed_`i'==0;
					};		
					};	
					
		* Sum per week;
			foreach status in worked unemployed inactive {;
			foreach week in w1 w2 w3 {;
				egen `week'oth_`status'_n = rowtotal(`week'oth_`status'_0-`week'oth_`status'_16) ;
				replace `week'oth_`status'_n = .  if `week'_hhemploymiss==1; 
				};
				};	
			drop w1oth_worked_0- w3oth_inactive_16;		
				
		
	* Employment by type of activity; 	
		* Employed in day work;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_daywork_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_daywork_`i'  = 1 if `week'_h9_`i'==1 | `week'_h13_`i'==1;
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_daywork_n = rowtotal(`week'oth_daywork_0-`week'oth_daywork_16) ;
				replace `week'oth_daywork_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_daywork_0-w3oth_daywork_16;
	 
		* Salaried;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_salaried_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_salaried_`i'  = 1 if (`week'_h10_`i'==1 | `week'_h11_`i'==1);
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_salaried_n = rowtotal(`week'oth_salaried_0-`week'oth_salaried_16) ;
				replace `week'oth_salaried_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_salaried_0-w3oth_salaried_16;
	 
	 	* Self-employed;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_self_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_self_`i'  = 1 if `week'_h6_`i'==1 | `week'_h8_`i'==1 | `week'_h7_`i'==1;
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_self_n = rowtotal(`week'oth_self_0-`week'oth_self_16) ;
				replace `week'oth_self_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_self_0-w3oth_self_16;
	 
	 	 
	 	* Gov works;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_gov_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_gov_`i'  = 1 if `week'_h12_`i'==1;
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_gov_n = rowtotal(`week'oth_gov_0-`week'oth_gov_16) ;
				replace `week'oth_gov_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_gov_0-w3oth_gov_16;
	 
	 * PW;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_himo_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_himo_`i'  = 1 if `week'_h12_himo_`i'==1;
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_himo_n = rowtotal(`week'oth_himo_0-`week'oth_himo_16) ;
				replace `week'oth_himo_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_himo_0-w3oth_himo_16;
	 
	 
	 * Other;
			foreach week in w1 w2 w3 {;
			foreach i of numlist 0/16 {;
				gen `week'oth_othjob_`i' = 0 if `week'_h1a_`i'==1 & `week'_h3_`i'==2 ;
				replace `week'oth_othjob_`i'  = 1 if `week'_h7_`i'==1 | `week'_h13_`i'==1;
				};		
				};
	
			foreach week in w1 w2 w3 {;
				egen `week'oth_othjob_n = rowtotal(`week'oth_othjob_0-`week'oth_othjob_16) ;
				replace `week'oth_othjob_n = .  if `week'_hhemploymiss==1; 
				};
				
				drop w1oth_othjob_0-w3oth_othjob_16;
	 	 
	 
	* Share of adults who worked;
		foreach status in worked unemployed inactive daywork salaried self gov himo othjob {;
		foreach week in w1 w2 w3 {;
				gen `week'oth_`status'_sh = `week'oth_`status'_n / `week'_nothadults;
					* we put to 0 households where there is no other hh member besides the woman;
					replace `week'oth_`status'_sh = 0 if `week'_nothadults == 0 & `week'_hhemploymiss==0;
				};
				};
				
				
	 
	 * Average number of adults other than the woman;
	 egen w123oth_mean_nothadults = rowmean(w1_nothadults w2_nothadults w3_nothadults);
	 
	 
	 *** Hours worked;
	* Per week;
		foreach week in w1 w2 w3 {; 
				gen `week'oth_hoursworked=0;
				lab var `week'oth_hoursworked "Hours worked by other HH members than woman in week `week'";
		foreach i of numlist 0/16 {;
				replace `week'oth_hoursworked = `week'oth_hoursworked + `week'_h16_`i' if `week'_h16_`i'>0 & `week'_h16_`i'<168;
				};
				replace `week'oth_hoursworked = . if `week'_hhemploymiss==1;
				};
					
			
*** Remuneration;			
		* missing stay 0 until the final labor income variable is created;
		foreach week in w1 w2 w3 {; 
				gen `week'oth_income_labor=0;
				lab var `week'oth_income_labor "Hours worked by other HH members than woman in week `week'";
		foreach i of numlist 0/16 {;
				replace `week'oth_income_labor = `week'oth_hoursworked + `week'_h18_`i' if `week'_h18_`i'>0 & `week'_h18_`i'!=. & `week'_h17_`i'==2;
				replace `week'oth_income_labor = `week'oth_hoursworked + `week'_h20_`i' if `week'_h20_`i'>0 & `week'_h20_`i'!=. & (`week'_h17_`i'==1 | `week'_h17_`i'==4 | `week'_h17_`i'==6) & `week'_h19_`i'==1;
				replace `week'oth_income_labor = `week'oth_hoursworked + (`week'_h20_`i'/2) if `week'_h20_`i'>0 & `week'_h20_`i'!=. & (`week'_h17_`i'==1 | `week'_h17_`i'==4 | `week'_h17_`i'==6) & `week'_h19_`i'==2;
				replace `week'oth_income_labor = `week'oth_hoursworked + (`week'_h20_`i'/4.3) if `week'_h20_`i'>0 & `week'_h20_`i'!=. & (`week'_h17_`i'==1 | `week'_h17_`i'==4 | `week'_h17_`i'==6) & `week'_h19_`i'==3;
				replace `week'oth_income_labor = `week'oth_hoursworked + (`week'_h21_`i'/4.3) if `week'_h21_`i'>0 & `week'_h21_`i'!=. & `week'_h17_`i'==3;
				};
				replace `week'oth_income_labor = . if `week'_hhemploymiss==1;
				};
		
	 
	* Average employment & unemployment over 3 weeks: number of adults and share of adults;
		foreach status in worked unemployed inactive daywork salaried self gov himo othjob {;
				egen w123oth_mean_`status'_n = rowmean(w1oth_`status'_n w2oth_`status'_n w3oth_`status'_n);
				egen w123oth_mean_`status'_sh = rowmean(w1oth_`status'_sh w2oth_`status'_sh w3oth_`status'_sh);
				};
				
				lab var w123oth_mean_worked_n 		"Average number of HH members other than woman employed status: over week 1 to 3";	
				lab var w123oth_mean_worked_sh 		"Average share of HH members other than woman employed status: over week 1 to 3";
				lab var w123oth_mean_unemployed_n 	"Average number of HH members other than woman unemployed status: over week 1 to 3";
				lab var w123oth_mean_unemployed_sh 	"Average share of HH members other than woman unemployed status: over week 1 to 3";
				lab var w123oth_mean_inactive_n 	"Average number of HH members other than woman inactive status: over week 1 to 3";
				lab var w123oth_mean_inactive_sh 	"Average share of HH members other than woman inactive status: over week 1 to 3";
				lab var w123oth_mean_daywork_n 		"Average number of HH members other than woman employed_daywork status: over week 1 to 3";
				lab var w123oth_mean_daywork_sh 	"Average share of HH members other than woman employed_daywork status: over week 1 to 3";
				lab var w123oth_mean_salaried_n 	"Average number of HH members other than woman employed_salaried status: over week 1 to 3";
				lab var w123oth_mean_salaried_sh 	"Average share of HH members other than woman employed_salaried status: over week 1 to 3";
				lab var w123oth_mean_self_n 		"Average number of HH members other than woman employed_self status: over week 1 to 3";
				lab var w123oth_mean_self_sh 		"Average share of HH members other than woman employed_self status: over week 1 to 3";
				lab var w123oth_mean_gov_n 			"Average number of HH members other than woman employed_gw status: over week 1 to 3";
				lab var w123oth_mean_gov_sh 		"Average share of HH members other than woman employed_gw status: over week 1 to 3";
				lab var w123oth_mean_himo_n 		"Average number of HH members other than woman employed_himo status: over week 1 to 3";
				lab var w123oth_mean_himo_sh 		"Average share of HH members other than woman employed_himo status: over week 1 to 3";
				lab var w123oth_mean_othjob_n 		"Average number of HH members other than woman employed_other status: over week 1 to 3";
				lab var w123oth_mean_othjob_sh		"Average share of HH members other than woman employed_other status: over week 1 to 3";
				
		foreach var in hoursworked income_labor {;		
		egen w123oth_mean_`var' = rowmean(w1oth_`var' w2oth_`var' w3oth_`var');
			};
			lab var w123oth_mean_hoursworked "Average hours worked, over the past 7 days, by other HH members than woman over week 1 to 3";		
			lab var w123oth_mean_income_labor "Average income from labor, over the past 7 days, by other HH members than woman over week 1 to 3";		
			
	

	****************;	
* Other income;
	#delimit;
	foreach week in w1 w2 w3 {;
		egen missotherincome`week'= rowmiss(`week'_fs5 `week'_fs6 `week'_fs7 `week'_fs8 `week'_fs9 `week'_fs10);
				replace missotherincome`week'=0 if inrange(missotherincome`week',0,4);
			replace missotherincome`week'=1 if inrange(missotherincome`week',5,6);
			
		
	gen otherincome_`week' = 0 if missotherincome`week'==0;
		label var otherincome_`week' "1 if HH received other income during `week'";
	gen otherincomeamt_`week' = 0 if missotherincome`week'==0;
		label var otherincomeamt_`week' "Amount (in FDJ) of other income received during `week'";
	foreach i of numlist 5/10 {;
		replace otherincome_`week' = 1 if `week'_fs`i'==1;
		replace otherincomeamt_`week'  = otherincomeamt_`week'  + `week'_fs`i'_fdj if `week'_fs`i'_fdj>=0 & `week'_fs`i'_fdj!=.;
		};
		};
		
	egen otherincome_w123 = rowmean(otherincome_w1 otherincome_w2 otherincome_w3);
		label var otherincome_w123 "1 if HH received other income (average week 1 to 3)";
	egen otherincomeamt_w123 = rowmean(otherincomeamt_w1 otherincomeamt_w2 otherincomeamt_w3);
		label var otherincomeamt_w123  "Average amount (in FDJ) of other income received week 1 to 3"; 	
	

* Total income;
	egen w123_mean_income_total = rowtotal(w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123);
		replace w123_mean_income_total = . if w123w_mean_remun==. & w123oth_mean_income_labor==. & otherincomeamt_w123==.;
		
		_pctile w123_mean_income_total, p(99.5);
		
		foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123_mean_income_total {;
			replace `var'=. if w123_mean_income_total>r(r1);
			};
		label var w123_mean_income_total "Average amount (in FDJ) of total income (week 1 to 3)";
		
* Total labor income;
		egen w123_mean_income_labor = rowtotal(w123w_mean_remun w123oth_mean_income_labor);
		replace w123_mean_income_labor = . if w123w_mean_remun==. & w123oth_mean_income_labor==.;
		
		_pctile w123_mean_income_total, p(99.5);
		
		foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123_mean_income_total {;
			replace `var'=. if w123_mean_income_total>r(r1);
			};
		
		
				
* ROBUSTNESS Total Income;

		foreach var in w123_mean_income_total w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123m_mean_remun {;
			gen l`var'= ln(`var');
			};
			
		label var lw123_mean_income_total "ln of total average income past 7 days";
		label var lw123w_mean_remun "ln of woman average labor income past 7 days";
		label var lw123oth_mean_income_labor "ln of other hh members average labor income past 7 days";
		label var lotherincomeamt_w123 "ln of other non-labor income past 7 days";
		label var lw123m_mean_remun "ln of husband average labor income past 7 days";
	
	foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123m_mean_remun {;
			gen tr05_`var'=`var';
			_pctile `var', p(99.5);
			replace tr05_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
				
		gen tr05_w123_mean_income_total = 0 if w123_mean_income_total!=.;
			foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 {;
				replace tr05_w123_mean_income_total = tr05_w123_mean_income_total + tr05_`var' if tr05_`var'>=0 & tr05_`var'!=.;
				};
	
	
	foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123m_mean_remun {;
			gen tr1_`var'=`var';
			_pctile `var', p(99);
			replace tr1_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
				
		gen tr1_w123_mean_income_total = 0 if w123_mean_income_total!=.;
			foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 {;
				replace tr1_w123_mean_income_total = tr1_w123_mean_income_total + tr1_`var' if tr1_`var'>=0 & tr1_`var'!=.;
				};
		
	foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 w123m_mean_remun {;
			gen tr5_`var'=`var';
			_pctile `var', p(95);
			replace tr5_`var'=r(r1) if `var'>r(r1) & `var'!=.;
			};
				
		gen tr5_w123_mean_income_total = 0 if w123_mean_income_total!=.;
			foreach var in w123w_mean_remun w123oth_mean_income_labor otherincomeamt_w123 {;
				replace tr5_w123_mean_income_total = tr5_w123_mean_income_total + tr5_`var' if tr5_`var'>=0 & tr5_`var'!=.;
				};	
				
			foreach i in 05 1 5 {;
				label var tr`i'_w123w_mean_remun "Average income from labor past 7 days by beneficiary (week 1-3) topcoded `i'%";
				label var tr`i'_w123oth_mean_income_labor "Average income from labor past 7 days by other HH members (week 1-3) topcoded `i'%";
				label var tr`i'_otherincomeamt_w123 "Average of other income (week 1-3) topcoded `i'%"; 
				label var tr`i'_w123_mean_income_total "Average amount (in FDJ) of total income (week 1-3) topcoded `i'%";
				label var tr`i'_w123m_mean_remun "Average income from labor past 7 days by husband (week 1-3) topcoded `i'%";
				};	
			
			
* Transferts;
	foreach week in w1 w2 w3 {;
		egen misstransfers`week'= rowmiss(`week'_fr1 `week'_fr2 `week'_fr3 `week'_fr4);
			replace misstransfers`week'=0 if inrange(misstransfers`week',0,2);
			replace misstransfers`week'=1 if inrange(misstransfers`week',3,4);
					
	gen transfers_`week' = 0 if misstransfers`week'==0;
		label var transfers_`week' "1 if HH made a transfer `week'";
	gen transfersamt_`week' = 0 if misstransfers`week'==0;
		label var transfersamt_`week' "Amount (in FDJ) of transfers made `week'";
	foreach i of numlist 1/4 {;
		replace transfers_`week' = 1 if `week'_fr`i'==1;
		replace transfersamt_`week' = transfersamt_`week' + `week'_fr`i'_fdj if `week'_fr`i'_fdj>=0 & `week'_fr`i'_fdj!=.;
		};
		};
		
	egen transfers_w123 = rowmean(transfers_w1 transfers_w2 transfers_w3);
		label var transfers_w123 "1 if HH made a transfer (average week 1 to 3)";
	egen transfersamt_w123 = rowmean(transfersamt_w1 transfersamt_w2 transfersamt_w3);
		label var transfersamt_w123 "Average amount (in FDJ) of transfers week 1 to 3"; 	
* Intra-HH transfers;
	foreach week in w1 w2 w3 {;
		egen missintrahhtransf`week'= rowmiss(`week'_ft1 `week'_fu1 `week'_fv1 `week'_fw1);
			replace missintrahhtransf`week'=0 if inrange(missintrahhtransf`week',0,2);
			replace missintrahhtransf`week'=1 if inrange(missintrahhtransf`week',3,4);
	
	* Money from woman to husband;				
		gen intrahhcash_wh_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_wh_`week' = 1 if `week'_ft1==1; 
			label var intrahhcash_wh_`week' "1 if woman gave money to husband `week'";
		
		gen intrahhcash_wh_amt_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_wh_amt_`week' = intrahhcash_wh_amt_`week' + `week'_ft3 if `week'_ft3>=0 & `week'_ft3!=.;
			foreach i of numlist 1/7 {;
				replace intrahhcash_wh_amt_`week' = intrahhcash_wh_amt_`week' + `week'_ft3_`i' if `week'_ft3_`i'>=0 & `week'_ft3_`i'!=.;
				};
				label var intrahhcash_wh_amt_`week' "Amount (in FDJ) of money woman gave to husband `week'";
		
	* Money from woman to other HH members;
		gen intrahhcash_woth_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_woth_`week' = 1 if `week'_fu1==1; 
			label var intrahhcash_woth_`week' "1 if woman gave money to other hh members (exc husband) `week'";
		
		gen intrahhcash_woth_amt_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_woth_amt_`week' = intrahhcash_woth_amt_`week' + `week'_fu3 if `week'_fu3>=0 & `week'_fu3!=.;
			foreach i of numlist 1/7 {;
				replace intrahhcash_woth_amt_`week' = intrahhcash_woth_amt_`week' + `week'_fu3_`i' if `week'_fu3_`i'>=0 & `week'_fu3_`i'!=.;
				};
				label var intrahhcash_woth_amt_`week' "Amount (in FDJ) of money woman gave to other hh members (exc husband) `week'";
	
	* Money from Husband to woman (as declared by woman);
		gen intrahhcash_hw_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_hw_`week' = 1 if `week'_fv1==1; 
			label var intrahhcash_hw_`week' "1 if husband gave money to benef woman `week'";
		
		gen intrahhcash_hw_amt_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_hw_amt_`week' = intrahhcash_hw_amt_`week' + `week'_fv3 if `week'_fv3>=0 & `week'_fv3!=.;
			foreach i of numlist 1/7 {;
				replace intrahhcash_hw_amt_`week' = intrahhcash_hw_amt_`week' + `week'_fv3_`i' if `week'_fv3_`i'>=0 & `week'_fv3_`i'!=.;
				};
				label var intrahhcash_hw_amt_`week' "Amount (in FDJ) of money husband gave money to benef woman `week'";

	* Money from Husband to other HH members (as declared by woman);
		gen intrahhcash_hoth_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_hoth_`week' = 1 if `week'_fw1==1; 
			label var intrahhcash_hoth_`week' "1 if husband gave money to other HH members `week'";
		
		gen intrahhcash_hoth_amt_`week' = 0 if missintrahhtransf`week'==0;
			replace intrahhcash_hoth_amt_`week' = intrahhcash_hoth_amt_`week' + `week'_fw3 if `week'_fw3>=0 & `week'_fw3!=.;
			foreach i of numlist 1/7 {;
				replace intrahhcash_hoth_amt_`week' = intrahhcash_hoth_amt_`week' + `week'_fw3_`i' if `week'_fw3_`i'>=0 & `week'_fw3_`i'!=.;
				};
				label var intrahhcash_hoth_amt_`week' "Amount (in FDJ) of money husband gave money to other HH members `week'";	
		};
	egen intrahhcash_wh_w123 = rowmean(intrahhcash_wh_w1 intrahhcash_wh_w2 intrahhcash_wh_w3);
		label var intrahhcash_wh_w123 "1 if woman gave money to husband (average week 1 to 3)";
	egen intrahhcash_wh_amt_w123 = rowmean(intrahhcash_wh_amt_w1 intrahhcash_wh_amt_w2 intrahhcash_wh_amt_w3);
		label var intrahhcash_wh_amt_w123 "Average amount (in FDJ) of money woman gave to husband week 1 to 3"; 	
				
	egen intrahhcash_woth_w123 = rowmean(intrahhcash_woth_w1 intrahhcash_woth_w2 intrahhcash_woth_w3);
		label var intrahhcash_woth_w123 "1 if woman gave money to other HH members (average week 1 to 3)";
	egen intrahhcash_woth_amt_w123 = rowmean(intrahhcash_woth_amt_w1 intrahhcash_woth_amt_w2 intrahhcash_woth_amt_w3);
		label var intrahhcash_woth_amt_w123 "Average amount (in FDJ) of money woman gave to other HH members week 1 to 3"; 	
	
	egen intrahhcash_hw_w123 = rowmean(intrahhcash_hw_w1 intrahhcash_hw_w2 intrahhcash_hw_w3);
		label var intrahhcash_hw_w123 "1 if husband gave money to benef woman (average week 1 to 3)";
	egen intrahhcash_hw_amt_w123 = rowmean(intrahhcash_hw_amt_w1 intrahhcash_hw_amt_w2 intrahhcash_hw_amt_w3);
		label var intrahhcash_hw_amt_w123 "Average amount (in FDJ) of money husband gave benef woman week 1 to 3"; 	
	
	egen intrahhcash_hoth_w123 = rowmean(intrahhcash_hoth_w1 intrahhcash_hoth_w2 intrahhcash_hoth_w3);
		label var intrahhcash_hoth_w123 "1 if husband gave money to other HH members (average week 1 to 3)";
	egen intrahhcash_hoth_amt_w123 = rowmean(intrahhcash_hoth_amt_w1 intrahhcash_hoth_amt_w2 intrahhcash_hoth_amt_w3);
		label var intrahhcash_hoth_amt_w123 "Average amount (in FDJ) of money husband gave to other HH members week 1 to 3"; 	


*************************;
* Savings;
	foreach week in w1 w2 w3 {;
		recode `week'_fs4 `week'm_fs4 (88=.) (77=.) (-88=.0) (-77=.);		
			
	* Savings over the past 7 days;				
		* Woman;
			gen w_saved_past7d_`week' = 0 if `week'_fs4!=.;
				replace w_saved_past7d_`week' = 1 if `week'_fs4==1; 
				label var w_saved_past7d_`week' "1 if woman saved over the past 7 days `week'";
			
			gen w_saved_past7d_amt_`week' = 0 if `week'_fs4!=.;
				replace w_saved_past7d_amt_`week' = `week'_fs4_fdj if `week'_fs4_fdj>=0 & `week'_fs4_fdj!=.; 
				label var w_saved_past7d_amt_`week' "Amount in fdj woman saved over the past 7 days `week'";
		
		* Man;
			gen m_saved_past7d_`week' = 0 if `week'm_fs4!=.;
				replace m_saved_past7d_`week' = 1 if `week'm_fs4==1; 
				label var m_saved_past7d_`week' "1 if husband saved over the past 7 days `week'";	
			
			gen m_saved_past7d_amt_`week' = 0 if `week'm_fs4!=.;
				replace m_saved_past7d_amt_`week' = `week'm_fs4_fdj if `week'm_fs4_fdj>=0 & `week'm_fs4_fdj!=.; 
				label var m_saved_past7d_amt_`week' "Amount in fdj husband saved over the past 7 days `week'";	
		};
			
					
		egen w_saved_past7d_w123 = rowmean(w_saved_past7d_w1 w_saved_past7d_w2 w_saved_past7d_w3);
			label var w_saved_past7d_w123 "1 if woman saved in last 7 days (average week 1 to 3)";		
			
		egen w_saved_past7d_amt_w123 = rowmean(w_saved_past7d_amt_w1 w_saved_past7d_amt_w2 w_saved_past7d_amt_w3);
			label var w_saved_past7d_amt_w123 "Amount in fdj woman saved in last 7 days (average week 1 to 3)";		
		
		egen m_saved_past7d_w123 = rowmean(m_saved_past7d_w1 m_saved_past7d_w2 m_saved_past7d_w3);
			label var m_saved_past7d_w123 "1 if husband saved in last 7 days (average week 1 to 3)";		

		egen m_saved_past7d_amt_w123 = rowmean(m_saved_past7d_amt_w1 m_saved_past7d_amt_w2 m_saved_past7d_amt_w3);
			label var m_saved_past7d_amt_w123 "Amount in fdj husband saved in last 7 days (average week 1 to 3)";

			drop w_saved_past7d_w1- m_saved_past7d_amt_w3;
		
		
	recode w3_fs42 w3_fs44 w3_fs48 w3_fs52 w3_fs55 w3_fs56 (88=.) (-88=.);
	
	** FOLLOWING DATA: we asked these questions in follow-up 2, 3 and 4 and only in week 3 (at endline we asked them every week, in the 4 survey rounds);
	* Tontine;	
		gen hh_tontine = 0 if w3_fs42!=.;
			replace hh_tontine = 1 if w3_fs42==1; 
			label var hh_tontine "1 if a hh member participates in a tontine";
			
		gen hh_tontine_weekly = 0 if hh_tontine!=.;
			replace hh_tontine_weekly = 1 if w3_fs44==1;
			replace hh_tontine_weekly = . if hh_tontine==1 & w3_fs44==.;
			label var hh_tontine_weekly "1 if weekly contributions to the tontine";

		gen hh_tontine_monthly = 0 if hh_tontine!=.;
			replace hh_tontine_monthly = 1 if w3_fs44==2;
			replace hh_tontine_monthly = . if hh_tontine==1 & w3_fs44==.;
			label var hh_tontine_monthly "1 if monthly contributions to the tontine";
			
		gen hh_tontine_lastcontr_days = 0 if hh_tontine!=.;
			replace hh_tontine_lastcontr_days = w3_interviewdatenum - date_deposit_tontine_num if w3_interviewdatenum > 0 & w3_interviewdatenum!=. & date_deposit_tontine_num >0 & date_deposit_tontine_num!=.;
			replace hh_tontine_lastcontr_days = . if hh_tontine==1 & (w3_interviewdatenum == . | date_deposit_tontine_num == .);  
			label var hh_tontine_lastcontr_days "Days since last contribution to the tontine";
			
		gen hh_tontine_lastcontr_amt = 0 if hh_tontine!=.;
			replace hh_tontine_lastcontr_amt = w3_fs46 if w3_fs46 > 0 & w3_fs46!=.;
			replace hh_tontine_lastcontr_amt = . if hh_tontine==1 & w3_fs46==.;
			label var hh_tontine_lastcontr_amt "Amount of last contribution in FDJ to the tontine";
			
	* Informal insurance;				
		gen hh_insurance = 0 if w3_fs48!=.;
			replace hh_insurance = 1 if w3_fs48==1; 
			label var hh_insurance "1 if a hh member participates in informal insurance";
			
		gen hh_insurance_lastcontr_days = 0 if hh_insurance!=.;
			replace hh_insurance_lastcontr_days = w3_interviewdatenum - date_deposit_insurance_num if w3_interviewdatenum > 0 & w3_interviewdatenum!=. & date_deposit_insurance_num >0 & date_deposit_insurance_num!=. & (w3_interviewdatenum >= date_deposit_insurance_num);
			replace hh_insurance_lastcontr_days = . if hh_insurance==1 & (w3_interviewdatenum == . | date_deposit_insurance_num == . | (w3_interviewdatenum < date_deposit_insurance_num));  
			label var hh_insurance_lastcontr_days "Days since last contribution to informal insurance";

		gen hh_insurance_lastcontr_amt = 0 if hh_insurance!=.;
			replace hh_insurance_lastcontr_amt = w3_fs51 if w3_fs51 > 0 & w3_fs51!=.;
			replace hh_insurance_lastcontr_amt = . if hh_insurance==1 & w3_fs51==.;
			label var hh_insurance_lastcontr_amt "Amount of last contribution in FDJ to informal insurance";
		* only one hh got money from insurance (w3_fs52-54);	
	* Has savings;				
		gen hh_savings = 0 if w3_fs55!=.;
			replace hh_savings = 1 if w3_fs55==1; 
			label var hh_savings "1 if a hh member has savings";
		gen hh_savings_amt = 0 if hh_savings!=.;
			replace hh_savings_amt = w3_fs56 if w3_fs56 > 0 & w3_fs56!=.;
			replace hh_savings_amt = . if hh_savings==1 & w3_fs56==.;
			label var hh_savings_amt "Amount of hh savings in FDJ";
	* Has savings or tontine or informal insurance;
		gen hh_anysavings_insurance = 0 if w_saved_past7d_w123!=. | m_saved_past7d_w123!=. | hh_tontine!=. | hh_insurance!=. | hh_savings!=.;
			replace hh_anysavings_insurance = 1 if inrange(w_saved_past7d_w123, 0.1, 1) | inrange(m_saved_past7d_w123, 0.1, 1) | hh_tontine==1 | hh_insurance==1 | hh_savings==1;
			label var hh_anysavings_insurance "1 if hh has any savings or insurance";
	
		*************************;
* Loans;
	* Grocery store loans;				
		gen loan_grocery = 0 if w3_fl1!=.;
			replace loan_grocery = 1 if w3_fl1==1; 
			label var loan_grocery "1 if the hh buys at the grocery store at credit";
		
		gen loan_grocery_amt = 0 if loan_grocery == 0;
			replace loan_grocery_amt = w3_fl2 if w3_fl2>0 & w3_fl2!=.; 
			label var loan_grocery_amt "Amount owed to the grocery store";
			
	* Loans;				
		gen loan = 0 if w3_fl3!=.;
			replace loan = 1 if w3_fl3==1; 
			label var loan "1 if hh has an outstanding loan";
		
		gen loan_amt = 0 if loan == 0;
			replace loan_amt = w3_fl4 if w3_fl4>0 & w3_fl4!=.; 
			label var loan_amt "Amount of outstanding loans";
	
	* Loan reimbursements (from expenditure section of husband questionnaire);
		gen loan_reimb = 0 if mmiss_expenses==0 & miss_expenses==0 ;
			replace loan_reimb = 1 if w2m_he7==1;
			replace loan_reimb = . if w2m_he7==.;
			lab var loan_reimb "1 if hh reimbursed a loan in last 30 days";	
		gen loan_reimb_amt = 0 if loan_reimb != . ;
			replace loan_reimb_amt = w2m_he7a if w2m_he7a!=. & w2m_he7a >= 0;  
			replace loan_reimb_amt = . if loan_reimb==1 & w2m_he7a==.;  
			lab var loan_reimb_amt "Amount of hh loan reimbursements in last 30 days (in FDJ)";		
*******************************************;
* School participation;
	gen nkids615 = 0 if missroster_w2==0;
	gen share_inschool615 = 0 if missroster_w2==0;
		forval i=0/16 {;
			replace nkids615 = nkids615 + 1 if inrange(w2_h5_`i', 6, 15) & w2_h1a_`i'==1; 
			replace share_inschool615 = share_inschool615 + 1 if inrange(w2_h5_`i', 6, 15) & w2_h25_`i'==1 & w2_h1a_`i'==1; 
			};
		foreach age in 615 {;
			replace share_inschool`age' = share_inschool`age' / nkids`age' ;
			};
	label var share_inschool615 "share of kids aged 6-15 in school";
	label var nkids615 "number of hh members aged 6-15";  
******************************************;
* Time use;
	foreach week in w1 w3 {;
	*** Beneficiary woman;
		* we replace by missing when secondary acivity = main act;
			forval i=1/20 {;
				replace `week'_l`i's=. if `week'_l`i's==`week'_l`i';
			};
		* We identify missing time use sections;
			egen misstime`week' = rowmiss(`week'_l1- `week'_l20e2);
			replace misstime`week' = 0 if misstime`week'<80;
			replace misstime`week' = 1 if misstime`week'>=80;
			label var misstime`week' "1 if non response to woman time use module `week'"; 
		* We compute time per category;
		foreach group in own study chores care work social other {;
			gen timewo_`group'_`week'= 0 if misstime`week'==0;
			};
		foreach group in benef adultwo girl neighbor manadult other {;
			gen timeychbs_`group'_`week'= 0 if misstime`week'==0;
			};
		gen `week'_newych = (`week'_l0e==1); 	
		foreach group in benef adultwo girl neighbor manadult other {;
			gen timeychto_`group'_`week'= 0 if misstime`week'==0 & `week'_newych==1;
			};
			forval i=1/20 {;
				if `i'==1 {;
					local j 300;
					} ; 
				if `i'>1 {;
					local j 60;
					} ; 
		replace timewo_own_`week' 		= timewo_own_`week' + `j' 	if  misstime`week'==0 & inrange(`week'_l`i',11,13);
		replace timewo_study_`week' 	= timewo_study_`week' + `j' if  misstime`week'==0 & inrange(`week'_l`i',21,23);
		replace timewo_chores_`week' 	= timewo_chores_`week' + `j' if  misstime`week'==0 & inrange(`week'_l`i',31,39);
		replace timewo_care_`week' 		= timewo_care_`week' + `j' 	if  misstime`week'==0 & inrange(`week'_l`i',51,52);
		replace timewo_work_`week' 		= timewo_work_`week' + `j' 	if  misstime`week'==0 & inrange(`week'_l`i',60,75);
		replace timewo_social_`week' 	= timewo_social_`week' + `j' if  misstime`week'==0 & inrange(`week'_l`i',81,89);
		replace timewo_other_`week' 	= timewo_other_`week' + `j' if  misstime`week'==0 & inrange(`week'_l`i', 91,93);
		
		replace timeychbs_benef_`week' 	= timeychbs_benef_`week' + `j' if misstime`week'==0 & `week'_l`i'e==0;
		replace timeychbs_adultwo_`week' = timeychbs_adultwo_`week' + `j' if misstime`week'==0 & (`week'_l`i'e==2 | `week'_l`i'e==3);
		replace timeychbs_girl_`week' 	= timeychbs_girl_`week' + `j' if misstime`week'==0 & `week'_l`i'e==5;
		replace timeychbs_neighbor_`week' = timeychbs_neighbor_`week' + `j' if misstime`week'==0 & `week'_l`i'e==7;
		replace timeychbs_manadult_`week' = timeychbs_manadult_`week' + `j' if misstime`week'==0 & (`week'_l`i'e==1 | `week'_l`i'e==4 | `week'_l`i'e==6);
		replace timeychbs_other_`week' 	= timeychbs_other_`week' + `j' if misstime`week'==0 & inrange(`week'_l`i'e, 8, 12);
			
		replace timeychto_benef_`week' 	= timeychto_benef_`week' + `j' if misstime`week'==0 & `week'_l`i'e2==0;
		replace timeychto_adultwo_`week' = timeychto_adultwo_`week' + `j' if misstime`week'==0 & (`week'_l`i'e2==2 | `week'_l`i'e2==3);
		replace timeychto_girl_`week' 	= timeychto_girl_`week' + `j' if misstime`week'==0 & `week'_l`i'e2==5;
		replace timeychto_neighbor_`week' = timeychto_neighbor_`week' + `j' if misstime`week'==0 & `week'_l`i'e2==7;
		replace timeychto_manadult_`week' = timeychto_manadult_`week' + `j' if misstime`week'==0 & (`week'_l`i'e2==1 | `week'_l`i'e2==4 | `week'_l`i'e2==6);
		replace timeychto_other_`week' = timeychto_other_`week' + `j' if misstime`week'==0 & inrange(`week'_l`i'e2, 8, 12);
				};
		* We turn to 0 youngest child (baseline) older than 5 years old;	
		foreach group in benef adultwo girl neighbor manadult other {;
		replace timeychbs_`group'_`week'= 0 if (`week'_l0c>=5 | `week'_l0c<0) & misstime`week'==0;
					};
		* We complete caregiver for youngest child today;
		foreach group in benef adultwo girl neighbor manadult other {;
		replace timeychto_`group'_`week'= timeychbs_`group'_`week' if timeychbs_`group'_`week'!=. & timeychto_`group'_`week'==.;
					};
		sum timeychbs_benef_`week'-timeychto_other_`week';
		foreach group in own study chores care work social other {;
		label var timewo_`group'_`week' "Time spent by beneficiary woman in `group' in previous day - `week'";
					};
		foreach group in benef adultwo girl neighbor manadult other {;
		label var timeychbs_`group'_`week' "Time of youngest child (baseline) care done by `group' in previous day - `week'";
		label var timeychto_`group'_`week' "Time of youngest child (today) care done by `group' in previous day - `week'";
					};
		drop `week'_newych;
	
*** Husband;
		* We replace by missing when secondary acivity = main act;
			forval i=1/20 {;
				replace `week'm_l`i's=. if `week'm_l`i's==`week'm_l`i';
				};
			recode `week'm_l1-`week'm_l20s (-88=.);	
		* We identify missing time use sections;
			egen misstime`week'm = rowmiss(`week'm_l1-`week'm_l20s);
			replace misstime`week'm = 0 if misstime`week'm<=20;
			replace misstime`week'm = 1 if misstime`week'm>20;
			label var misstime`week'm "1 if non response to man time use module `week'"; 
			
		* We compute time per category;
		foreach group in own study chores care work social other {;
			gen timeman_`group'_`week'= 0 if misstime`week'm==0;
			};

			forval i=1/20 {;
			
				if `i'==1 {;
					local j 300;
					} ; 
				if `i'>1 {;
					local j 60;
					} ; 
			replace timeman_own_`week' = timeman_own_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',11,13);
			replace timeman_study_`week' = timeman_study_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',21,23);
			replace timeman_chores_`week' = timeman_chores_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',31,39);
			replace timeman_care_`week' = timeman_care_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',51,52);
			replace timeman_work_`week' = timeman_work_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',60,75);
			replace timeman_social_`week' = timeman_social_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i',81,89);
			replace timeman_other_`week' = timeman_other_`week' + `j' if  misstime`week'm==0 & inrange(`week'm_l`i', 91,93);
			};
		foreach group in own study chores care work social other {;
				label var timeman_`group'_`week' "Time spent by husband in `group' in previous day - `week'";
				};
		};
* We create average over the two weeks;
		foreach group in own study chores care work social other {;
			egen timewo_`group'_w13 = rowmean(timewo_`group'_w1 timewo_`group'_w3);
			};
		foreach group in own study chores care work social other {;
			egen timeman_`group'_w13 = rowmean(timeman_`group'_w1 timeman_`group'_w3);
			};
		foreach group in benef adultwo girl neighbor manadult other {;
			egen timeychbs_`group'_w13 = rowmean(timeychbs_`group'_w1 timeychbs_`group'_w3);
					};
		foreach group in benef adultwo girl neighbor manadult other {;
			egen timeychto_`group'_w13 = rowmean(timeychto_`group'_w1 timeychto_`group'_w3);
					};
		foreach group in own study chores care work social other {;
				label var timewo_`group'_w13 "Average time spent by woman beneficiary in `group' in previous day (week 1 & 3)";
				label var timeman_`group'_w13 "Average time spent by husband in `group' in previous day (week 1 & 3)";
				};
		foreach group in benef adultwo girl neighbor manadult other {;
					label var timeychbs_`group'_w13 "Average time of youngest child (baseline) care done by `group' in previous day (week 1&3)";
					label var timeychto_`group'_w13 "Average time of youngest child (today) care done by `group' in previous day (week 1&3)";
					};		
	
	
************************************;
* Breast-feeding and Food diversity;
	* continued breastfeeding C3: Est-ce que cet enfant est maintenant allaité ?
	* exclusive breastfeeding C4: Est-ce que %C2A% a été exclusivement allaité CES DERNIERES 24 HEURES,  C'EST-A-DIRE DU MOMENT OU VOUS VOUS ETES LEVEE HIER JUSQU AUX  MEMES HEURES CE MATIN ?;

*********************************
* EXCLUSIVE ;
gen breastfeed_continued = 0 if  w3_c2c!=.  & ((agemonths_ych>=12 & agemonths_ych<24));
	replace breastfeed_continued = 1 if w3_c3==1 & ((agemonths_ych>=12 & agemonths_ych<24)); 
	label var breastfeed_continued "kids 12-23 months who still receive breast milk";
	
gen ebf_d=0  if (w3_c3!=. | w3_c4!=.);
replace ebf_d=1 if w3_c4==1;
lab var ebf_d "child exclusively breastfed in the past 24 hrs (only bf children)";
#delimit cr
recode w3_c7* (-99=.) (-88=.)

egen miss_childfood = rowmiss(w3_c7e_*)
tab miss_childfood
	replace miss_childfood = 0 if miss_childfood<10 
	recode miss_childfood (10=1)
* We define 7 food groups
	gen graintubers_24hch = ((w3_c7e_1>0 & w3_c7e_1!=.) | (w3_c7e_2>0 & w3_c7e_2!=.))
	gen va_fruitveg_24hch = ((w3_c7e_8>0 & w3_c7e_8!=.) | (w3_c7e_9>0 & w3_c7e_9!=.))
	gen othfruitveg_24hch = ((w3_c7e_10>0 &w3_c7e_10!=.)) 
	gen meat_24hch = ((w3_c7e_5>0 & w3_c7e_5!=.) | (w3_c7e_6>0 & w3_c7e_6!=.))
	gen eggs_24hch = (w3_c7e_7>0 & w3_c7e_7!=.)
	gen legumesnts_24hch = (w3_c7e_3>0 & w3_c7e_3!=.)
	gen milkprod_24hch = (w3_c7e_4>0 & w3_c7e_4!=.)
	* dropped indicator kid6-59  which was present at baseline
	* Children 6-59;	
	egen child_divers659 = rowtotal(graintubers_24hch-milkprod_24h) if agemonths_ych>=6 & agemonths_ych<=59 & miss_childfood==0
	gen ichild_divers659 = 0 if child_divers659!=.
		replace ichild_divers659 = 1 if inrange(child_divers659,4,7) | (inrange(child_divers659,3,7) & w3_c3==1) 
	gen child_animal659 = (meat_24hch==1 | eggs_24hch==1 | milkprod_24hch==1) if agemonths_ych>=6 & agemonths_ych<=59 & miss_childfood==0
	gen child_vitafood659 = (va_fruitveg_24hch==1 | (w3_c7e_2>0 & w3_c7e_2!=.)) if agemonths_ych>=6 & agemonths_ych<=59 & miss_childfood==0

	* Children 6-23;	
	egen child_divers623 = rowtotal(graintubers_24hch-milkprod_24h) if agemonths_ych>=6 & agemonths_ych<24 & miss_childfood==0
	gen ichild_divers623 = 0 if child_divers623!=.
		replace ichild_divers623 = 1 if inrange(child_divers623,4,7) | ( (inrange(child_divers623,3,7)) & w3_c3==1)
	gen child_animal623 = (meat_24hch==1 | eggs_24hch==1 | milkprod_24hch==1) if agemonths_ych>=6 & agemonths_ych<24 & miss_childfood==0
	gen child_vitafood623 = (va_fruitveg_24hch==1 | (w3_c7e_2>0 & w3_c7e_2!=.)) if agemonths_ych>=6 & agemonths_ych<24 & miss_childfood==0
	
	* Children 24-59;	
	egen child_divers2459 = rowtotal(graintubers_24hch-milkprod_24h) if agemonths_ych>=24 & agemonths_ych<=59 & miss_childfood==0
	gen ichild_divers2459 = 0 if child_divers2459!=.
		replace ichild_divers2459 = 1 if inrange(child_divers2459,4,7) | (inrange(child_divers2459,3,7) & w3_c3==1) 
	gen child_animal2459 = (meat_24hch==1 | eggs_24hch==1 | milkprod_24hch==1) if agemonths_ych>=24 & agemonths_ych<=59 & miss_childfood==0
	gen child_vitafood2459 = (va_fruitveg_24hch==1 | (w3_c7e_2>0 & w3_c7e_2!=.)) if agemonths_ych>=24 & agemonths_ych<=59 & miss_childfood==0
	label var child_divers659 "Index of food diversity in last 24h: youngest child aged 6-59 months"
	label var ichild_divers659 "Indicator for youngest child aged 6-59 months has a diversified diet"
	label var child_animal659 "Indicator for youngest child aged 6-59 months ate food rich in proteins in last 24h"
	label var child_vitafood659 "Indicator for youngest child aged 6-59 months ate food rich in vitamins in last 24h"

	label var child_divers623 "Index of food diversity in last 24h: youngest child aged 6-23 months"
	label var ichild_divers623 "Indicator for youngest child aged 6-23 months has a diversified diet"
	label var child_animal623 "Indicator for youngest child aged 6-23 months ate food rich in proteins in last 24h"
	label var child_vitafood623 "Indicator for youngest child aged 6-23 months ate food rich in vitamins in last 24h"

	label var child_divers2459 "Index of food diversity in last 24h: youngest child aged 24-59 months"
	label var ichild_divers2459 "Indicator for youngest child aged 24-59 months has a diversified diet"
	label var child_animal2459 "Indicator for youngest child aged 24-59 months ate food rich in proteins in last 24h"
	label var child_vitafood2459 "Indicator for youngest child aged 24-59 months ate food rich in vitamins in last 24h"
	
	drop  graintubers_24hch- milkprod_24hch  
	
	* We look at Food Diversity by food category
	
	local i 1
	foreach group in grain tubers legumesnts milkprod meat giblets eggs vitamina vegetables othfruitveg {
		gen `group'_659 = 0 if agemonths_ych>=6 & agemonths_ych<=59 & miss_childfood==0
			replace `group'_659 = 1 if w3_c7e_`i'>0 & w3_c7e_`i'!=. & agemonths_ych>=6 & agemonths_ych<=59
			label var `group'_659 "Indicator for youngest child aged 6-59 months ate `group' in last 24h"
			
		gen `group'_623 = 0 if agemonths_ych>=6 & agemonths_ych<=23 & miss_childfood==0
			replace `group'_623 = 1 if w3_c7e_`i'>0 & w3_c7e_`i'!=. & agemonths_ych>=6 & agemonths_ych<=23
			label var `group'_623 "Indicator for youngest child aged 6-23 months ate `group' in last 24h"
			
			local i = `i' +1
			} 
						
		
	***********************************************
* Food diversity: pregnant and lactating women

/*
w3_c7f_1           combien de fois avez-vous mang du... riz, galette (bl ou sorgho, mais), pain, be
w3_c7f_2           combien de fois avez-vous mang du... pommes de terre ou autre racines dans ces 2
w3_c7f_3           combien de fois avez-vous mang du... haricots blancs/fves blancs, fves noires, l
w3_c7f_4           combien de fois avez-vous mang du... fromage ou yaourts, lait caill dans ces 24
w3_c7f_5           combien de fois avez-vous mang du... viande, volaille, poisson, coquillages, inc
w3_c7f_6           combien de fois avez-vous mang du... abats [par ex: foie, cur, rognons, gsiers,
w3_c7f_7           combien de fois avez-vous mang du... ufs dans ces 24 heures, c'est-a-dire de qua
w3_c7f_8           combien de fois avez-vous mang du... carottes, mangue, papaye, goyave, melon jau
w3_c7f_9           combien de fois avez-vous mang du... lgumes feuilles vertes, ou sauce feuilles
w3_c7f_10          combien de fois avez-vous mang du... tout autre fruit et lgume [par ex: fruits 
*/

* Women
gen woman=0
replace woman=1 if (w3_c3 == 1) | (w3_c5 == 1)
label var woman "Indicator for pregnant or lactating woman in Section C"
recode w3_c7f_* (-99=.) (-88=.) 
egen miss_wofood = rowmiss(w3_c7f_*)
tab miss_wofood
	replace miss_wofood = 0 if miss_wofood<10 
	recode miss_wofood (10=1)
	* We define 7 food groups
	gen graintubers_24hw = ((w3_c7f_1>0 & w3_c7f_1!=.) | (w3_c7f_2>0 & w3_c7f_2!=.)) 
	gen va_fruitveg_24hw = ((w3_c7f_8>0 & w3_c7f_8!=.) | (w3_c7f_9>0 & w3_c7f_9!=.))
	gen othfruitveg_24hw = ((w3_c7f_10>0 &w3_c7f_10!=.)) 
	gen meat_24hw = ((w3_c7f_5>0 & w3_c7f_5!=.) | (w3_c7f_6>0 & w3_c7f_6!=.))
	gen eggs_24hw = (w3_c7f_7>0 & w3_c7f_7!=.)
	gen legumesnts_24hw = (w3_c7f_3>0 & w3_c7f_3!=.)
	gen milkprod_24hw = (w3_c7f_4>0 & w3_c7f_4!=.)
	egen woman_divers = rowtotal(graintubers_24hw - milkprod_24hw) if woman==1 & miss_wofood==0 
	gen iwoman_divers = 0 if woman_divers!=.
		replace iwoman_divers = 1 if inrange(woman_divers,4,7)
	gen woman_animal = (meat_24hw==1 | eggs_24hw==1 | milkprod_24hw==1) if woman==1 & miss_wofood==0
	gen woman_vitafood = (va_fruitveg_24hw==1 | (w3_c7f_2>0 & w3_c7f_2!=.)) if woman==1 & miss_wofood==0
	drop graintubers_24hw - milkprod_24hw
	label var woman_divers "Index of food diversity in last 24h: pregnant or lactating woman"
	label var iwoman_divers "Indicator for pregnant or lactating woman has a diversified diet"
	label var woman_animal "Indicator for pregnant or lactating woman ate food rich in proteins in last 24h"
	label var woman_vitafood "Indicator for pregnant or lactating woman ate food rich in vitamins in last 24h"
****************************************
****************************************
* FOOD DIVERSITY: 4 out of 10 categories (Clara's do file definition)
*** Children

	* we define dummies for each food group
	forval x=1/10 {
		gen d`x'=(w3_c7e_`x'>0 & w3_c7e_`x'!=.)
		}

	egen child_divers659_10 = rowtotal(d1-d10) if miss_childfood==0 & agemonths_ych>=6 & agemonths_ych<=59
	gen ichild_divers659_10 = 0 if child_divers659_10!=.
		replace ichild_divers659_10 = 1 if (inrange(child_divers659_10,3,10) & w3_c3==1) | inrange(child_divers659_10,4,10)
	
	
	egen child_divers623_10 = rowtotal(d1 - d10) if miss_childfood==0 & agemonths_ych>=6 & agemonths_ych<24
	gen ichild_divers623_10 = 0 if child_divers623_10!=.
		replace ichild_divers623_10 = 1 if (inrange(child_divers623_10, 3, 10) & w3_c3==1) | inrange(child_divers623_10, 4, 10)

	label var child_divers659_10 "Index of food diversity in last 24h (10 food categories): youngest child aged 6-59 months"
	label var ichild_divers659_10 "Indicator for youngest child aged 6-59m has a diversified diet (4/10)"
	label var child_divers623_10 "Index of food diversity in last 24h (10 food categories): youngest child aged 6-23 months"
	label var ichild_divers623_10 "Indicator for youngest child aged 6-23m has a diversified diet (4/10)"
			
	drop d1-d10

*** Woman
	forval x=1/10 {
		gen dw`x'=(w3_c7f_`x'>0 & w3_c7f_`x'!=.)
		}

	egen woman_divers_10 = rowtotal(dw1-dw10) if woman==1 & miss_wofood==0 
	gen iwoman_divers_10 = 0 if woman_divers_10!=.
		replace iwoman_divers_10 = 1 if inrange(woman_divers_10,4,10)

	label var woman_divers_10 "Index of food diversity in last 24h (10 food categories): pregnant or lactating woman"
	label var iwoman_divers_10 "Indicator for pregnant or lactating woman has a diversified diet (4/10)"

	drop dw1-dw10

****************************************	
* FOOD SECURITY - from baseline definition
for num 1/6: recode w3_dX 2=0
egen miss_fs = rowmiss(w3_d1 w3_d2 w3_d3 w3_d4 w3_d5 w3_d6)
	replace miss_fs = 0 if miss_fs<6
	replace miss_fs = 1 if miss_fs==6
	

gen notenoughfood = (w3_d1==1)
	label var notenoughfood "Indicator for being concerned about not having enough food in last 7 days"

gen fs_worsequality = (w3_d2==1)
gen fs_smallerportions = (w3_d3==1)
gen fs_fewermeals = (w3_d4==1)
gen fs_lessfoodadults = (w3_d5==1)
gen fs_borrowfood = (w3_d6==1) 

egen foodinsecurity = rowtotal(fs_worsequality fs_smallerportions fs_fewermeals fs_lessfoodadults fs_borrowfood)
	label var foodinsecurity "Index of food insecurity in last 7 days"
	

foreach var in notenoughfood foodinsecurity {
	replace `var'=. if miss_fs==1
	}
	tab1 notenoughfood foodinsecurity
	drop miss_fs fs_worsequality- fs_borrowfood

	// coping strategy index as per p 10 of 
// http://documents.wfp.org/stellent/groups/public/documents/ena/wfp253658.pdf
for num 2/6: recode w3_dXj .=0 if w3_dX==0 & w3_dX!=.
gen foodCopingStrat = w3_d2j + w3_d3j + w3_d4j + 3 * w3_d5j + 2 * w3_d6j
lab var foodCopingStrat "coping strategy index for food security as per WFP"
tab foodCopingStrat, m

# delimit;
* Mental Health;
		foreach person in w3 w3m {;	
	
		* Standard coding;
				foreach i of numlist 1 2 {;
					gen mentalh`i'_`person' = `person'_sm`i';
						recode mentalh`i'_`person' 1=10 2=20 3=30 4=40 5=50 -77=. -88=. 77=. 88=.;
						recode mentalh`i'_`person' 10=4 20=3 30=2 40=1 50=0;
						label var mentalh`i'_`person' "item `i' mental health score `person'";
						};

		* Reverse coding;
				foreach i of numlist 3 4 5 {;
					gen mentalh`i'_`person' = `person'_sm`i';
						recode mentalh`i'_`person' 1=10 2=20 3=30 4=40 5=50 -77=. -88=. 77=. 88=.;
						recode mentalh`i'_`person' 10=0 20=1 30=2 40=3 50=4;
						label var mentalh`i'_`person' "item `i' mental health score `person'";
						};
		egen mentalhealth_miss_`person' = rowmiss(mentalh1_`person' - mentalh5_`person');
		egen `person'_mentalhealth = rowtotal(mentalh1_`person' - mentalh5_`person') if mentalhealth_miss_`person'<= 1;
		alpha mentalh1_`person' - mentalh5_`person', asis;
		drop mentalhealth_miss_`person' mentalh1_`person' - mentalh5_`person';
		};
		rename w3_mentalhealth w_mentalhealth;
		rename w3m_mentalhealth m_mentalhealth;
		label var w_mentalhealth "Indicator of mental health, beneficiary woman";
		label var m_mentalhealth  "Indicator of mental health, husband";
*********************************;
* Attrition, take-up & delegation (as declared by women);
	* Attrition: we use actual responses to labor supply section;
	gen attrition_woman = 0;
		replace attrition_woman = 1 if w123w_mean_employed==.; 
		label var attrition_woman "1 if woman did not answed labor supply at follow-up"; 
	gen attrition_husband = 0;
		replace attrition_husband = 1 if w123m_mean_employed==.;  
		label var attrition_husband "1 if husband did not answer labor supply at follow-up";
	gen attrition_household = (attrition_woman==1 & attrition_husband==1);
		label var attrition_household  "1 if household not surveyed at follow-up";		
*********************************;
* Take-up & delegation (as declared by women);
	egen miss_sectiono_w1 = rowmiss(w1_o*);
		tab miss_sectiono_w1;
		replace miss_sectiono_w1=0 if inrange(miss_sectiono_w1, 0,23);
		replace miss_sectiono_w1=1 if miss_sectiono_w1==24;
		tab miss_sectiono_w1;
		label var miss_sectiono_w1 "1 if Section O missing in week 1";
		
	egen miss_sectiono_w2 = rowmiss(w2_o*);
		tab miss_sectiono_w2;
		replace miss_sectiono_w2=0 if inrange(miss_sectiono_w2, 0,19);
		replace miss_sectiono_w2=1 if inrange(miss_sectiono_w2, 22,23);
		label var miss_sectiono_w2 "1 if Section O missing in week 2";
	egen miss_sectiono_w3 = rowmiss(w3_o*);
		tab miss_sectiono_w3;
		replace miss_sectiono_w3=0 if inrange(miss_sectiono_w3, 0,6);
		replace miss_sectiono_w3=1 if miss_sectiono_w3==7;
		label var miss_sectiono_w3 "1 if Section O missing in week 3";
	* Heard about the program;
		gen knowsprogram = 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace knowsprogram = 1 if w1_o1==1 | w2_o1==1;
			label var knowsprogram "1 if have heard about the program";
	* Got offered the program;	
		gen gotprgoffer = 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace gotprgoffer = 1 if w1_o2==1 | w2_o2==1;		
			label var gotprgoffer "1 if got the program offered";
	* Take-up;	
	foreach week in w1 w2 {;	
		gen `week'_hhtakeup = 0 if miss_sectiono_`week'==0;
			replace `week'_hhtakeup = 1 if `week'_o4==1;  
			replace `week'_hhtakeup = . if `week'_o2==1 & `week'_o4==.;
			};
		
		*there are contradictions between weekly labor data and knowledge program section; 
		count if w1_hhtakeup==0 & (w1w_employed_himo==1 | w1m_employed_himo==1);
		* TBCH: 66 cases
		count if w2_hhtakeup==0 & (w2w_employed_himo==1 | w2m_employed_himo==1);
		* TBCH: 7 cases - 2 we can solve with week 1 data. There remains 5 cases;
			replace w2_hhtakeup=1 if w2_hhtakeup==0 & (w2w_employed_himo==1 | w2m_employed_himo==1) & w1_hhtakeup==1 & (w1w_employed_himo==1 | w1m_employed_himo==1);  
		
		* we use week 2 and then complete with week 1 and then we complete with data on HIMO work;
		gen hhtakeup = w2_hhtakeup;
			replace hhtakeup = w1_hhtakeup if w2_hhtakeup==. & w1_hhtakeup!=.; 
			replace hhtakeup = 1 if (w123w_mean_employed_himo==1 | w123m_mean_employed_himo==1) & hhtakeup==.;
				count if hhtakeup == 0 & (inrange(w123w_mean_employed_himo, 0.2,1) | inrange(w123m_mean_employed_himo, 0.2,1));
				* TBCH: 75 cases. mostly coming from followup 1;
			label var hhtakeup "1 if hh participated in the program"; 
					
				drop w1_hhtakeup w2_hhtakeup; 
				
	* Delegation;
		* if answers to both weeks, we use week 2 (in many cases they did not understand the question about the delegation in week 1);
		* if week 2 missing, we complete with week 1 when there is info;
		
		foreach week in w1 w2 {;
			gen `week'_delegated = 0 if (miss_sectiono_`week'==0);
				replace `week'_delegated  = 1 if `week'_o4a==2 | `week'_o4a==3;  
				replace `week'_delegated = . if (`week'_o2==1 & `week'_o4==.);
			
			gen `week'_delegated_person = 0 if (miss_sectiono_`week'==0);
				replace `week'_delegated_person = 1 if `week'_o5==2;
				replace `week'_delegated_person = 2 if `week'_o5==1 | `week'_o5==3;
				replace `week'_delegated_person = 3 if `week'_o5a==1 | `week'_o5a==3;
				replace `week'_delegated_person = 4 if `week'_o5a==2 | `week'_o5a==4;
				replace `week'_delegated_person = . if (`week'_o4a==2 | `week'_o4a==3) & `week'_o5==. & `week'_o5a==.;
				};
					
		
		gen delegated = w2_delegated;
			replace delegated  = w1_delegated if w2_delegated==. & w1_delegated!=.; 
				count if delegated == 1 & (inrange(w123w_mean_employed_himo, 0.2,1));
				* TBCH: 16 cases. from the 3 rounds;
				label var delegated "1 if woman delegated public works";
				drop w1_delegated w2_delegated;
		
		**************************;
		* Corrections delgation & woman/man/other member work on HIMO;
			* tab w123w_mean_employed_himo delegated, miss;
			* edit id8 *w_employed_himo w123w_mean_employed_himo w123w_mean_employed_daywork w123w_mean_remun *m_employed_himo w123m_mean_employed_himo *oth_himo_sh w123oth_mean_himo_sh w1_o* w2_o* if delegated==1 & inrange(w123w_mean_employed_himo, .3,1);
		#delimit;
			foreach hhid in 21520 15396 13258 21831 19922 21170 23284 12672 19643 22481 20553 20950 12748 21808 20014 22473 
			22412 22425 {;
			foreach var in w1w_employed_himo w2w_employed_himo w3w_employed_himo w123w_mean_employed_himo {;
					replace `var'= 0 if id8 == `hhid';
					};
					};
					
			foreach hhid in 22487 22364 23179 21021 21842 21827 {;
			foreach var in w1m_employed_himo w2m_employed_himo w3m_employed_himo w123m_mean_employed_himo {;
					replace `var'= 0 if id8 == `hhid';
					};
					};		
					
			foreach hhid in 22444 21593 15326 22556 22453 22412 20008 22425 {;
				replace delegated=1 if id8 == `hhid';
					};
					

			foreach hhid in 19719 23179 19813 19599 20333 23155 21355 {;
			foreach var in w123oth_mean_himo_n w123oth_mean_himo_sh w1oth_himo_n w2oth_himo_n w3oth_himo_n w1oth_himo_sh w2oth_himo_sh w3oth_himo_sh {;
					replace `var'= 0 if id8 == `hhid';
					};
					};		
		
		* Corrections hh take-up & woman/man/other member work on HIMO;		
		replace hhtakeup = 1 if (inrange(w123w_mean_employed_himo, 0.3, 1) | inrange(w123m_mean_employed_himo, 0.3, 1) | inrange(w123oth_mean_himo_n, 0.1, 1)) & hhtakeup==0;
		
		
		* Corrections take-up & delegation;
		* edit id8 w123w_mean_employed_himo w123m_mean_employed_himo w123oth_mean_himo_n w1_o* w2_o* if hhtakeup==1 & delegated==.;
		foreach hhid in 20138 21537 22384 20337 21605 19929 23199 18810 {;
			replace delegated = 0 if id8 == `hhid';
					};
	
		* Dummy for worked in HIMO (to be used in table on take-up);		
		gen woman_employed_himo = 1 if inrange(w123w_mean_employed_himo, 0.1,1);
			replace woman_employed_himo = 0 if w123w_mean_employed_himo==0;
		
		gen husband_employed_himo = 1 if inrange(w123m_mean_employed_himo, 0.1,1);
			replace husband_employed_himo = 0 if w123m_mean_employed_himo==0;
		
		gen other_employed_himo = 1 if inrange(w123oth_mean_himo_n, 0.1,1);
			replace other_employed_himo = 0 if w123oth_mean_himo_n==0;
 
	
	
		**************************;
		
		gen delegated_person = w2_delegated_person;
			replace delegated_person = w1_delegated_person if w2_delegated_person==. & w1_delegated_person!=.;
				gen delegated_woman = 0 if delegated_person!=.;
				replace delegated_woman = 1 if delegated_person == 1 | delegated_person == 3;
				label var delegated_woman "1 if delegated public works to a woman"; 
			gen delegated_man = 0 if delegated_person!=.;
				replace delegated_man = 1 if delegated_person == 2 | delegated_person == 4;
				label var delegated_man "1 if delegated public works to a man"; 
			gen delegated_womanhh = 0 if delegated_person!=.;
				replace delegated_womanhh = 1 if delegated_person == 1;
				label var delegated_womanhh "1 if delegated public works to a female HH member"; 
			gen delegated_manhh = 0 if delegated_person!=.;
				replace delegated_manhh = 1 if delegated_person == 2;
				label var delegated_manhh "1 if delegated public works to a male HH member"; 
			gen delegated_womanout = 0 if delegated_person!=.;
				replace delegated_womanout = 1 if delegated_person == 3;
				label var delegated_womanout "1 if delegated public works to a female non-HH member"; 
			gen delegated_manout = 0 if delegated_person!=.;
				replace delegated_manout = 1 if delegated_person == 4;
				label var delegated_manout "1 if delegated public works to a male non-HH member"; 
							
		
		* Reasons delegation;
			 * We only have the reasons of delegation for waves 3 and 4;
			gen deleg_reason = 0 if delegated!=. & (followup_n==3 | followup_n==4);
				replace deleg_reason = 1 if delegated==1 & (w2_o6_raison == 3 | w2_o6_raison == 4);
				replace deleg_reason = 2 if delegated==1 & (w2_o6_raison == 1 | w2_o6_raison == 2);
				replace deleg_reason = 3 if delegated==1 & (w2_o6_raison == 5 | w2_o6_raison == 6 | w2_o6_raison == 7);
				replace deleg_reason = 4 if delegated==1 & w2_o6_raison == 8;
				replace deleg_reason = 5 if delegated==1 & (w2_o6_raison == 9 | w2_o6_raison == 10);
				replace deleg_reason = 6 if delegated==1 & (w2_o6_raison == 11 | w2_o6_raison == 12);

				replace deleg_reason = 1 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 3 | w1_o6_raison == 4);
				replace deleg_reason = 2 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 1 | w1_o6_raison == 2);
				replace deleg_reason = 3 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 5 | w1_o6_raison == 6 | w2_o6_raison == 7);
				replace deleg_reason = 4 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 8);
				replace deleg_reason = 5 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 9 | w1_o6_raison == 10);
				replace deleg_reason = 6 if deleg_reason == 0 & delegated==1 & (w1_o6_raison == 11 | w1_o6_raison == 12);
				
				replace deleg_reason = . if delegated ==1 & (w1_o6_raison==. | w1_o6_raison==88) & (w2_o6_raison==. | w2_o6_raison==88);
				replace deleg_reason = . if delegated ==1 & deleg_reason==0;
							
				local j 1;
				foreach reason in mandatory pregnant12 childcare woill otherill other {;
					gen deleg_reas_`reason' = 0 if deleg_reason!=.;
					replace deleg_reas_`reason'= 1 if deleg_reason == `j';
					local j = `j'+ 1;
					};
			drop w1_delegated_person w2_delegated_person delegated_person deleg_reason;
			label var deleg_reas_mandatory "1 if delegated bc 3rd trimester or child 0-40 days";
			label var deleg_reas_pregnant12 "1 if delegated bc pregnant 1st or 2nd trimester"; 
			label var deleg_reas_childcare "1 if delageted bc had to care children (above 40 days)"; 
			label var deleg_reas_woill "1 if delegated bc she was ill";  
			label var deleg_reas_otherill "1 if delegated bc other HH member was ill"; 
			label var deleg_reas_other "1 if delegated bc of other reason"; 
		* Interaction between reasons for not working and mandatory delegation;
			
			gen nowork_notfind_delegmandat = 0 if w123w_reasnowork_cannotfind!=. & deleg_reas_mandatory!=.;
				replace nowork_notfind_delegmandat = 1 if w123w_reasnowork_cannotfind > 0 & w123w_reasnowork_cannotfind<=1 & deleg_reas_mandatory==1;
			
			gen nowork_family_delegmandat = 0 if w123w_reasnowork_family!=. & deleg_reas_mandatory!=.;
				replace nowork_family_delegmandat = 1 if w123w_reasnowork_family > 0 & w123w_reasnowork_family <= 1 & deleg_reas_mandatory==1;
				
			gen nowork_looking_delegmandat = 0 if w123w_reasnowork_looking!=. & deleg_reas_mandatory!=.;
			replace nowork_looking_delegmandat = 1 if w123w_reasnowork_looking > 0 & w123w_reasnowork_looking <= 1 & deleg_reas_mandatory==1;
			label var nowork_notfind_delegmandat "1 if could not find a job and mandatory to delegate PW";
			label var nowork_family_delegmandat "1 if did not work due to family and mandatory to delegate PW";
			label var nowork_looking_delegmandat "1 if looking for a job and mandatory to delegate PW";
		* Share of money kept by the target woman;
		foreach week in w1 w2 {;
			count if `week'_o8!=. & `week'_o10!=.; 
			gen `week'_pay = 0 if delegated==1;
				replace `week'_pay = `week'_o8 if `week'_o8>0 & `week'_o8!=. & delegated==1;
				replace `week'_pay = `week'_o10 if `week'_o10>0 & `week'_o10!=. & delegated==1;	
				replace `week'_pay = . if `week'_pay==0;
			gen `week'_sharerule = 1 - (`week'_o11 / `week'_pay) if `week'_o11>=0 & `week'_o11!=.;
				};
		gen sharerule = w2_sharerule;
			replace sharerule =  w2_sharerule if sharerule==. & w1_sharerule!=.;
			label var sharerule "share of last payment kept by woman who delegated";
			drop w1_pay w1_sharerule w2_pay w2_sharerule;	
		* Woman Status: pregnant and/or children below 5;
			* We do not have these questions for followup 1;
		gen pk_pregnant = 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_pregnant = 1 if w1_o12==1 | w2_o12==1;
			replace pk_pregnant = . if w1_o12==. & w2_o12==.;
						
		gen pk_pregnant3t = 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_pregnant3t = 1 if inrange(w1_o13,7,9) | inrange(w2_o13,7,9);
			replace pk_pregnant3t = . if pk_pregnant == .; 
			
		gen pk_pregnant12t = 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_pregnant12t = 1 if inrange(w1_o13,1,6) | inrange(w2_o13,1,6);
			replace pk_pregnant12t = . if pk_pregnant == .;
		gen pk_child06= 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_child06 = 1 if w1_o15==1 | w2_o15==1;
			replace pk_child06 = . if w1_o14==. & w2_o14==. ;
		gen pk_child623= 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_child623 = 1 if w1_o15==2 | w1_o15==3 | w2_o15==2 | w2_o15==3;
			replace pk_child623 = . if w1_o14==. & w2_o14==. ;
		gen pk_child2459= 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0;
			replace pk_child2459 = 1 if inrange(w1_o15,4,7) | inrange(w2_o15,4,7);
			replace pk_child2459 = . if w1_o14==. & w2_o14==. ;			
			
		* Participation to nutrition sessions;
			* We do not have these questions for followup 1 (we start asking for it in week 3 of FU2 and then we asked every week until FU4-W3);
			* Some corrections;
			foreach week in w1 w2 w3 {;
				replace `week'_o16 = 1 if inrange(`week'_o18, 1, 2);
				};
		gen pk_partfoyer= 0 if miss_sectiono_w1==0 | miss_sectiono_w2==0 | miss_sectiono_w3==0;
			replace pk_partfoyer = 1 if w1_o16==1 | w2_o16==1 | w3_o16==1;
			replace pk_partfoyer = . if w1_o16==. & w2_o16==. & w3_o16==.;
		gen pk_partfoyer_femme= 0 if pk_partfoyer!=.;
			replace pk_partfoyer_femme = 1 if w1_o18==1 | w2_o18==1 | w3_o18==1;
			replace pk_partfoyer = . if pk_partfoyer==1 & (w1_o18==. | w1_o18==88) & (w2_o18==. | w2_o18==88) & (w3_o18==. | w3_o18==88);
		gen pk_partfoyer_enf= 0 if pk_partfoyer!=.;
			replace pk_partfoyer_enf = 1 if w1_o18==2 | w2_o18==2 | w3_o18==2;
			replace pk_partfoyer_enf = . if pk_partfoyer==1 & (w1_o18==. | w1_o18==88) & (w2_o18==. | w2_o18==88) & (w3_o18==. | w3_o18==88);
			label var pk_pregnant3t "1 if preganant 3rd trimester(pk)";
			label var pk_pregnant12t "1 if preganant 1st or 2nd trimester(pk)"; 
			label var pk_child06 "1 if child 0-6 months old"; 
			label var pk_child623 "1 if child 6-23 months old"; 
			label var pk_child2459 "1 if child 24-59 months old";  
			label var pk_partfoyer	"1 if participated to nutrition session"; 
			label var pk_partfoyer_femme	"1 if participated to pregnant woman nutrition session"; 
			label var pk_partfoyer_enf	"1 if participated to a child 0-2 nutrition session"; 
			
	gen bs_income_nonlabor = 0 if (bs_income_pension!=. | bs_income_govngo!=. | bs_income_transfert!=. | bs_income_other!=. );
	replace bs_income_nonlabor = 1 if (bs_income_pension==1 | bs_income_govngo==1 | bs_income_transfert==1 | bs_income_other==1);
	label var bs_income_nonlabor "Indicator for HH had non-labor income in last 12 months";


* We create a dummy variable for the top quintile of baseline per capita food expenditures;
	gen bs_quint5_exppc_food = 0 if bs_exppc_food!=.;
		_pctile bs_exppc_food, p(80);
		replace bs_quint5_exppc_food = 1 if bs_exppc_food >r(r1) & bs_exppc_food!=.;
		label var bs_quint5_exppc_food "1 if quintile 5 of baseline food per capita expenditures";
* We create a variable income - (expenditures, savings, insurance, debt repayment) to check data quality;
		#delimit;
		set more off;
		gen income_accounting = w123_mean_income_total;
				replace income_accounting  = income_accounting - (exp_total / 4.3) if exp_total>0 & exp_total!=.;
				replace income_accounting  = income_accounting - w_saved_past7d_amt_w123 if w_saved_past7d_amt_w123 > 0 & w_saved_past7d_amt_w123!=.; 
				replace income_accounting  = income_accounting - m_saved_past7d_amt_w123 if m_saved_past7d_amt_w123 > 0 & m_saved_past7d_amt_w123!=.; 
				replace income_accounting  = income_accounting - hh_insurance_lastcontr_amt if hh_insurance_lastcontr_amt>0 & hh_insurance_lastcontr_amt!=.; 
				replace income_accounting  = income_accounting - (loan_reimb_amt / 4.3) if loan_reimb_amt>0 & loan_reimb_amt!=.;
								
				label var income_accounting "Amount in fdj of income minus exp sav ins debt repay over the past 7 days";
save "$path\data_analysis\midline_analysis", replace;
