clear
version 14
use "$path\data_analysis\midline_analysis.dta", clear


***********************************************************************************
* TABLE 2 ATTRITION
global attritionrate attrition_woman attrition_husband 
#delimit ;
global attrition 
	bs_eligible3 bs_hh_enceinte bs_hh_enfant3 bs_members bs_enfant5 bs_enfant615 bs_adults bs_propscolarise615 bs_headmale bs_headage bs_headnoeduc 		 bs_benefage bs_benefnoeduc
	bs_wo_inactive bs_wo_unemployed bs_wo_employed
	bs_wo_daywork_rel bs_wo_self_rel bs_wo_salaried_rel bs_wo_other_rel 
	bs_members_shinactive bs_members_shunemployed bs_members_shemployed 
	bs_members_shdaywork_rel bs_members_shself_rel bs_members_shsalaried_rel bs_members_shother_rel
	bs_income_labor bs_lincome_labor
	bs_income_transfert bs_income_govngo bs_income_pension bs_income_other bs_transfer_extrahh
	bs_exppc_total bs_exppc_food bs_exppc_healthedu bs_exppc_other bs_share_food bs_share_healthedu bs_share_other
	bs_lexppc_total bs_lexppc_food
	pmt_upper50
	bs_ichild_divers659 bs_child_animal659 bs_child_vitafood659 
	bs_ichild_divers623 bs_child_animal623 bs_child_vitafood623 
	bs_iwoman_divers bs_woman_animal bs_woman_vitafood
	bs_ichild_divers659_10 bs_ichild_divers623_10 bs_iwoman_divers_10
	bs_notenoughfood bs_foodinsecurity
	bs_w_partdecision_index bs_w_tookdecision_index bs_index_mobility_fa ;
		#delimit cr
	preserve
	gen vars=""
	gen N=.
	gen space1=""
	gen n_control=.
	gen mean_control=.
	gen sd_control=.
	gen space2=""
	gen coef_treatment=.
	gen stars_treatment=""
	gen p_treatment=.
	gen se_treatment=.
	local i 0
	foreach var in $attritionrate  {
	local i=`i'+1
	local x : variable label `var'
	replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=r(mean) if _n==`i'
		replace sd_control=r(sd) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' i.strata
	replace N=e(N) if _n==`i'
			replace coef_`x'=_b[`x'] if _n==`i' 
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
			}
	}
	outsheet vars-se_treatment using "$path\output\Table2_mid.txt"  if _n<100 , replace
	restore
	
***********************************************************************************
* TABLES A1 & A2 MID
#delimit ;
global balance 
	bs_eligible3 bs_members bs_enfant5 bs_enfant615 bs_adults bs_propscolarise615 bs_headmale bs_headage bs_headnoeduc bs_benefage bs_benefnoeduc 
	bs_wo_inactive bs_wo_unemployed bs_wo_employed
	bs_wo_daywork_rel bs_wo_self_rel bs_wo_salaried_rel 
	bs_members_shinactive bs_members_shunemployed bs_members_shemployed 
	bs_members_shdaywork_rel bs_members_shself_rel bs_members_shsalaried_rel 
	bs_income_labor bs_lincome_labor bs_income_nonlabor bs_transfer_extrahh
	bs_exppc_total bs_exppc_food bs_exppc_healthedu bs_exppc_other bs_lexppc_total bs_lexppc_food pmt_upper50
	bs_w_partdecision_index bs_w_tookdecision_index bs_index_mobility_fa ;
#delimit cr
gen women 	= (attrition_woman==0)
gen men 	= (attrition_husband==0)
foreach group in women men {
	preserve
	gen vars=""
	gen N=.
	gen space1=""
	gen n_control=.
	gen mean_control=.
	gen sd_control=.
	gen space2=""
	gen coef_treatment=.
	gen stars_treatment=""
	gen p_treatment=.
	local i 0
	foreach var in $balance  {
	local i=`i'+1
	local x : variable label `var'
	replace vars="`x'" if _n==`i'
	sum `var' if `group'==1 & treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=r(mean) if _n==`i'
		replace sd_control=r(sd) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' i.strata if `group'==1
	replace N=e(N) if _n==`i'
			replace coef_`x'=_b[`x'] if _n==`i' 
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
		}
	}
	outsheet vars-p_treatment using "$path\output\TableA12_`group'.txt"  if _n<100 , replace
	restore
	}

***********************************************************************************
* TABLE A1 & A2 ATTRITION Stats (which repeat Table 2)
global attritionrate attrition_woman attrition_husband 
#delimit ;
global attrition 
	bs_eligible3 bs_hh_enceinte bs_hh_enfant3 bs_members bs_enfant5 bs_enfant615 bs_adults bs_propscolarise615 bs_headmale bs_headage bs_headnoeduc 		 bs_benefage bs_benefnoeduc
	bs_wo_inactive bs_wo_unemployed bs_wo_employed
	bs_wo_daywork_rel bs_wo_self_rel bs_wo_salaried_rel bs_wo_other_rel 
	bs_members_shinactive bs_members_shunemployed bs_members_shemployed 
	bs_members_shdaywork_rel bs_members_shself_rel bs_members_shsalaried_rel bs_members_shother_rel
	bs_income_labor bs_lincome_labor
	bs_income_transfert bs_income_govngo bs_income_pension bs_income_other bs_transfer_extrahh
	bs_exppc_total bs_exppc_food bs_exppc_healthedu bs_exppc_other bs_share_food bs_share_healthedu bs_share_other
	bs_lexppc_total bs_lexppc_food
	pmt_upper50
	bs_ichild_divers659 bs_child_animal659 bs_child_vitafood659 
	bs_ichild_divers623 bs_child_animal623 bs_child_vitafood623 
	bs_iwoman_divers bs_woman_animal bs_woman_vitafood
	bs_ichild_divers659_10 bs_ichild_divers623_10 bs_iwoman_divers_10
	bs_notenoughfood bs_foodinsecurity
	bs_w_partdecision_index bs_w_tookdecision_index bs_index_mobility_fa ;
		#delimit cr
	preserve
	gen vars=""
	gen N=.
	gen space1=""
	gen n_control=.
	gen mean_control=.
	gen sd_control=.
	gen space2=""
	gen coef_treatment=.
	gen stars_treatment=""
	gen p_treatment=.
	gen se_treatment=.
	local i 0
	foreach var in $attritionrate  {
	local i=`i'+1
	local x : variable label `var'
	replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=r(mean) if _n==`i'
		replace sd_control=r(sd) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' i.strata
	replace N=e(N) if _n==`i'
			replace coef_`x'=_b[`x'] if _n==`i' 
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
			}
	}
	outsheet vars-se_treatment using "$path\output\TableA12_attrition.txt"  if _n<100 , replace
	restore
	
***********************************************************************************
* TABLE 3 DELEGATION
	preserve
	global delegation delegated_womanhh delegated_manhh delegated_womanout delegated_manout 
	gen vars=""
	gen space1=" "
	gen space2=.
	gen space3=" "
	gen n_treatment=.
	gen mean_treatment=""
	gen sd_treatment=""
	local i 0
	foreach var of global delegation {
	local i=`i'+1
	local x : variable label `var'
	replace vars="`x'" if _n==`i'
		sum `var' if treatment==1
			replace n_treatment=r(N) if _n==`i'
			replace mean_treatment=string(round(r(mean),.001)) if _n==`i'
			replace mean_treatment="0"+mean_treatment if (substr(mean_treatment,1,1)=="." | substr(mean_treatment,1,2)=="-.") &  _n==`i'
			replace sd_treatment=string(round(r(sd),.001)) if _n==`i'
			replace sd_treatment="0"+sd_treatment if (substr(sd_treatment,1,1)=="." | substr(sd_treatment,1,2)=="-.") &  _n==`i'
			replace sd_treatment="0"+sd_treatment if (substr(sd_treatment,1,1)=="." | substr(sd_treatment,1,2)=="-.") & _n==`i'
			}
	outsheet vars-sd_treatment using "$path\output\table3_mid_delegation.txt"  if _n<100 , replace
restore
	
***********************************************************************************
* CONTROLS
#delimit ;
global controls 
	bs_members bs_enfant5 bs_enfant615 bs_headmale bs_headage bs_benefage  
	bs_wo_employed bs_wo_unemployed
	bs_members_shinactive bs_members_shunemployed bs_members_shdaywork_rel 
	bs_quint5_exppc_food 
	bs_members_d bs_enfant5_d bs_enfant615_d bs_headmale_d bs_headage_d bs_benefage_d 
	bs_wo_employed_d bs_wo_unemployed_d
	bs_members_shinactive_d bs_members_shunemployed_d bs_members_shdaywork_rel_d
	bs_quint5_exppc_food_d ;
#delimit cr
	foreach var in $controls {
		gen `var'_d= (`var'==.)
		replace `var'=0 if `var'_d==1
		}
***********************************************************************************
***********************************************************************************
* TABLE 3 TAKE_UP DELEGATION REGRESSIONS
global takeup_del hhtakeup woman_employed_himo delegated husband_employed_himo
* Group of globals
global main_tables takeup_del
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
		*replace sd_control="["+sd_control+"]" if _n==`i' 
	foreach x in treatment {
	xi: reg `var' `x' ${controls} i.strata i.followup_n
	replace N=e(N) if _n==`i'
			*replace coef_`x'=_b[`x'] if _n==`i' 
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
		}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\table3_mid_`group'.txt"  if _n<100 , replace
	restore
	}
		
***********************************************************************************
***********************************************************************************
* TABLES 4-9, A5
#delimit ;
global able4 
		w123w_mean_inactive w123w_mean_unemployed w123w_mean_employed 
		w123w_mean_employed_daywork w123w_mean_employed_salaried w123w_mean_employed_selfempl w123w_mean_employed_gw 
		w123w_mean_hoursworked
		w123oth_mean_inactive_sh w123oth_mean_unemployed_sh w123oth_mean_worked_sh 
		w123oth_mean_daywork_sh w123oth_mean_salaried_sh w123oth_mean_self_sh w123oth_mean_gov_sh 
		w123oth_mean_hoursworked
		w123m_mean_inactive w123m_mean_unemployed w123m_mean_employed 
		w123m_mean_employed_daywork w123m_mean_employed_salaried w123m_mean_employed_selfempl w123m_mean_employed_gw 
		w123m_mean_hoursworked;		
global able5 timewo_own_w13  timewo_study_w13  timewo_chores_w13  timewo_care_w13  timewo_work_w13  timewo_social_w13  timewo_other_w13 
             timeman_own_w13 timeman_study_w13 timeman_chores_w13 timeman_care_w13 timeman_work_w13 timeman_social_w13 timeman_other_w13 
		     timeychto_benef_w13 timeychto_adultwo_w13 timeychto_girl_w13 timeychto_neighbor_w13 timeychto_manadult_w13 timeychto_other_w13;
global able6  	w123_mean_income_total w123w_mean_remun w123oth_mean_income_labor w123m_mean_remun otherincome_w123 otherincomeamt_w123
			intrahhcash_wh_w123 intrahhcash_wh_amt_w123  
			intrahhcash_hw_w123 intrahhcash_hw_amt_w123;
global able7 	exppc_total exppc_durables exppc_nondurables exppc_food lexppc_total lexppc_durables lexppc_nondurables lexppc_food
			hh_anysavings_insurance
			loan_grocery loan_grocery_amt loan ;
global able8 exp_husband_clothes exp_woman_clothes exp_adultmen_khat_tabac ;
global able9  w_mentalhealth m_mentalhealth;
global ableA5 ichild_divers659 child_animal659 child_vitafood659 
		  ichild_divers623 child_animal623 child_vitafood623
		  ichild_divers2459 child_animal2459 child_vitafood2459
		  iwoman_divers woman_animal woman_vitafood
		  ichild_divers659_10 ichild_divers623_10 iwoman_divers_10
				  notenoughfood foodinsecurity foodCoping;
				  #delimit cr
* Group of globals
global main_tables able4 able5 able6 able7 able8 able9 ableA5 
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
		*replace sd_control="["+sd_control+"]" if _n==`i' 
	foreach x in treatment {
	xi: reg `var' `x' ${controls} i.strata i.followup_n
		replace N=e(N) if _n==`i'
			*replace coef_`x'=_b[`x'] if _n==`i' 
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
			}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'_mid.txt"  if _n<100 , replace
	restore
	}

***********************************************************************************
***********************************************************************************
* APPENDIX TABLE B2. Comparison of results from the main analysis and from selecting baseline covariate using a double lasso procedure, Midline results
use "$path\data_analysis\midline_analysis.dta", clear
#delimit ;
global controls 
	bs_members bs_enfant5 bs_enfant615 bs_headmale bs_headage bs_benefage  
	bs_wo_employed bs_wo_unemployed
	bs_members_shinactive bs_members_shunemployed bs_members_shdaywork_rel 
	bs_quint5_exppc_food 
	bs_members_d bs_enfant5_d bs_enfant615_d bs_headmale_d bs_headage_d bs_benefage_d 
	bs_wo_employed_d bs_wo_unemployed_d
	bs_members_shinactive_d bs_members_shunemployed_d bs_members_shdaywork_rel_d
	bs_quint5_exppc_food_d ;
global ableB3
	w123w_mean_inactive 		w123w_mean_unemployed 		w123w_mean_employed 
	w123m_mean_inactive 		w123m_mean_unemployed 		w123m_mean_employed 
	w123oth_mean_inactive_sh 	w123oth_mean_unemployed_sh 	w123oth_mean_worked_sh 
	w123_mean_income_total lw123_mean_income_total
	lexppc_total lexppc_nondurables lexppc_food;
#delimit cr
	foreach var in $controls {
		gen `var'_d= (`var'==.)
		replace `var'=0 if `var'_d==1
		}

**************************************************************************************
* APPENDIX TABLE B3
* PANEL A. Subset outcomes with controls. 
global main_tables ableB2
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' ${controls} i.strata i.followup_n
		replace N=e(N) if _n==`i'
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
		}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'A.txt"  if _n<100 , replace
	restore
	}

**************************************************************************************
* APPENDIX TABLE B2
* PANEL B. Subset outcomes without controls
global main_tables ableB2
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' i.strata i.followup_n
		replace N=e(N) if _n==`i'
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
			}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'B.txt"  if _n<100 , replace
	restore
	}
	

**************************************************************************************
* APPENDIX TABLE B2
* PANEL C. Subset double lasso for controls
global main_tables ableB2

cap tab strata, g(strata_)

foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
		foreach x in treatment {
pdslasso `var' `x' (${controls} strata_*), partial(strata_*) lopt(prestd)
		replace N=e(N) if _n==`i'
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
			}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'C.txt"  if _n<100 , replace
	restore
	}

***********************************************************************************
***********************************************************************************
* APPENDIX TABLE B1. Comparison of results from the main analysis and from using a different set of strata variables, Midline results
use "$path\data_analysis\midline_analysis.dta", clear
#delimit ;
global controls 
	bs_members bs_enfant5 bs_enfant615 bs_headmale bs_headage bs_benefage  
	bs_wo_employed bs_wo_unemployed
	bs_members_shinactive bs_members_shunemployed bs_members_shdaywork_rel 
	bs_quint5_exppc_food 
	bs_members_d bs_enfant5_d bs_enfant615_d bs_headmale_d bs_headage_d bs_benefage_d 
	bs_wo_employed_d bs_wo_unemployed_d
	bs_members_shinactive_d bs_members_shunemployed_d bs_members_shdaywork_rel_d
	bs_quint5_exppc_food_d ;
global ableB1
	w123w_mean_inactive 		w123w_mean_unemployed 		w123w_mean_employed 
	w123m_mean_inactive 		w123m_mean_unemployed 		w123m_mean_employed 
	w123oth_mean_inactive_sh 	w123oth_mean_unemployed_sh 	w123oth_mean_worked_sh 
	w123_mean_income_total lw123_mean_income_total
	lexppc_total lexppc_nondurables lexppc_food;
#delimit cr
	foreach var in $controls {
		gen `var'_d= (`var'==.)
		replace `var'=0 if `var'_d==1
		}

**************************************************************************************
* APPENDIX TABLE B1
* PANEL A. Subset outcomes with controls
global main_tables ableB1
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' ${controls} i.strata i.followup_n
		replace N=e(N) if _n==`i'
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
		}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'A.txt"  if _n<100 , replace
	restore
	}
			
**************************************************************************************
* APPENDIX TABLE B1
* PANEL B. Different strata

egen strata_robtest=group(current_benef rsite rtypefoyer)

global main_tables ableB1
foreach group in $main_tables {
preserve
gen vars=""
gen space1=" "
gen N=.
gen space2=" "
gen n_control=.
gen mean_control=""
gen sd_control=""
gen space3=" "
gen coef_treatment=""
gen stars_treatment=""
gen p_treatment=.
gen se_treatment=.
local i 1
foreach var in $`group'  {
local x : variable label `var'
replace vars="`x'" if _n==`i'
	sum `var' if treatment==0
		replace n_control=r(N) if _n==`i'
		replace mean_control=string(round(r(mean),.001)) if _n==`i'
		replace mean_control="0" + mean_control if (substr(mean_control,1,1)=="." | substr(mean_control,1,2)=="-.") &  _n==`i'
		replace sd_control=string(round(r(sd),.001)) if _n==`i'
		replace sd_control="0" + sd_control if (substr(sd_control,1,1)=="." | substr(sd_control,1,2)=="-.") &  _n==`i'
		replace mean_control=subinstr(mean_control,"0-","-0",.) if _n==`i'
	foreach x in treatment {
	xi: reg `var' `x' ${controls} i.strata_robtest i.followup_n
		replace N=e(N) if _n==`i'
			replace coef_`x'=string(round(_b[`x'],.001)) if _n==`i'
			replace coef_`x'="0"+coef_`x' if (substr(coef_`x',1,1)=="." | substr(coef_`x',1,2)=="-.") &  _n==`i'
			replace coef_`x'=subinstr(coef_`x',"0-","-0",.) if _n==`i'
			replace se_`x'=_se[`x'] if _n==`i'
			test `x'=0 
			replace p_`x'= r(p) if _n==`i'
			replace stars_`x'="*" if r(p)<0.1 & r(p)>=0.05 & _n==`i'
			replace stars_`x'="**" if r(p)<0.05 & r(p)>=0.01 & _n==`i'
			replace stars_`x'="***" if r(p)<0.01 & _n==`i'
			replace stars_`x'=" " if r(p)>=0.1 & _n==`i'
		}
		local i=`i'+ 1
			}
	outsheet vars-se_treatment using "$path\output\T`group'B.txt"  if _n<100 , replace
	restore
	}

	
	
