**************************************************************
use "$path\data_original\dji_baseline.dta", clear
qui log using "$path\output\stats_misc.txt",text replace
* SEC 4.1
* "95% of beneficiaries were married"
tab benefmar,m
* FN 11
* "In 90 percent of households, the beneficiary's husband is identified as the head. Otherwise, she is the head (5 percent) or daughter of the head (4 percent)."
tab relation,m
qui log close

**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
qui log using "$path\output\stats_misc.txt", append
* SEC 5.1 
*"There is slightly lower take-up in the fourth wave of the program; take-up for waves 1-4 was respectively 4 out of 126, 2 out of 113, 5 out of 122, and 10 out of 120." 
tab hhtakeup follow if treatment==1, col
qui log close 
**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
qui log using "$path\output\stats_misc.txt", append
* SEC 5.1
* 68 percent of delegations were to a woman
tab delegated_woman if delegated==1 & treatment==1 & delegated_man~=.
qui log close

**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
keep if delegated==1 & treatment == 1 & (followup_n==3 | followup_n==4)
replace deleg_reas_other=1 if (deleg_reas_mandatory==.&deleg_reas_childcare==.&deleg_reas_woill==.&deleg_reas_otherill==. &deleg_reas_other==.)

qui foreach var in deleg_reas_mandatory  deleg_reas_pregnant12   deleg_reas_woill   deleg_reas_childcare      deleg_reas_otherill    deleg_reas_other  {
			replace `var'=0 if `var'==.
				}
replace deleg_reas_mandatory=1 if  deleg_reas_pregnant12 ==1
drop deleg_reas_pregnant12
label var deleg_reas_mandatory "Deleg reason: mandatory"
qui log using "$path\output\stats_misc.txt", append
* SEC 5.1 
*"Among the women who delegated the offer, just over a quarter delegate due to ineligibility imposed by the program on women who are pregnant or have very young infants (0-40 days old);  
*15 percent of the women who delegate their participation in the program declare to have been sick at the time they received the job offer. 
*Among the few remaining cases of delegation, caring for another household member is the main reason for not accepting the job offer (32 percent due to childcare constraints and 11 percent were related to the caring for a sick household member). 
*Another 15 percent of delegations have no specific reason reported." 
des deleg_re*
sum deleg_reas_mandatory  deleg_reas_childcare    deleg_reas_woill    deleg_reas_otherill    deleg_reas_other 
qui log close


**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
gen bottom2q=quint_pmtedam_urban==1|quint_pmtedam_urban==2 if quint_pmtedam_urban~=.
qui log using "$path\output\stats_misc.txt", append
* SEC 4.2 
* "Seventy three percent of the households are drawn from the bottom two quintiles of an asset index in urban Djibouti (based on the EDAM 2017)."
sum bottom2q 
qui log close

**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
sort quint_pmtedam_urban
qui log using "$path\output\stats_misc.txt", append
* SEC 5.1 
* "We do notice that the extent of own participation (as opposed to delegation) decreases with higher wealth as measured by an asset index"
tab quint_pmtedam_urban  if treatment ==1  	, sum(delegated)	
qui log close

**************************************************************
use "$path\data_analysis\midline_analysis.dta", clear
qui log using "$path\output\stats_misc.txt", append
* SEC 3
* At midline, most (93%) of women in the control households (all of whom would get the offer in the future) did know of the program.
tab know if treatment==0
qui log close

**************************************************************
use "$path\data_analysis\endline_analysis", clear
keep id8 bs_exppc_total w_id1 group
ren w_id1 site
ren bs_exppc_total exppc_total
gen time=0
tempfile baseline
save `baseline'

use "$path\data_analysis\endline_analysis", clear
keep id8 f_exppc_total  w_id1 group
ren w_id1 site
ren f_exppc_total exppc_total
gen end=1
tempfile end
save `end'

use "$path\data_analysis\midline_analysis", clear
keep id8 exppc_total  w1_id1 group
ren w1_id1 site
gen mid=1
tempfile mid
save `mid'

use `baseline'
append using `mid'
append using `end'
replace time=. if (group=="groupA" | group=="B") & (mid==1 | end==1) // look only at controls after Baseline

replace time=1 if group=="groupC" & (site==3|site==4|site==5) 	& mid==1
replace time=2 if group=="groupC" & (site==1|site==2) 			& mid==1
replace time=3 if group=="groupD" & (site==3|site==4|site==5)  	& mid==1
replace time=4 if group=="groupC" & (site==3|site==4|site==5)  	& end==1
replace time=5 if group=="groupD" & (site==1|site==2)  			& mid==1
replace time=6 if group=="groupC" & (site==1|site==2) 			& end==1
replace time=7 if group=="groupD" & (site==3|site==4|site==5)	& end==1
replace time=8 if group=="groupD" & (site==1|site==2)			& end==1
label define time 0 "2014_JanMar" 1 "2014 June" 2 "2014 Sept" 3 "2015 Jan" 4 "2015 Mar" 5 "2015 May" 6 "2015 June" 7 "2015 Oct" 8 "2016 Jan"
label values time time
qui log using "$path\output\stats_misc.txt", append
* Footnote 16: 
* Notably, we did not find any evidence for this after examining time patterns in total per capita expenditure for control households while leveraging 8 survey data points (month/years) from the baseline through to the last endline surveys (see Table A1). 
tab time
xi: reg expp i.time
qui log close


**************************************************************
use "$path\data_analysis\endline_analysis", clear
qui log using "$path\output\stats_misc.txt", append
* Sec 5.2 "At endline, women were asked whether they intended to look for a job in the subsequent 6 months, 
* and about 30 percent of women, regardless of treatment status, expressed this intension"
* In the next 6 months, do you intend to look for a job or start your own business (any type of income/production business)?
tabstat w123w_willlookjob_6m , by(treatment)
qui log close

**************************************************************
* bL ineligible
use "$path\data_original\dji_baseline.dta", clear
gen status=1 if preg_trim3==1
replace status=1 if agemonths_ych<=2
tab treat status,m row


